package com.kxs.common.excel.aop;

import com.kxs.common.core.util.R;
import com.kxs.common.excel.annotation.ResponseExcel;
import com.kxs.common.excel.handler.SheetWriteHandler;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.MethodParameter;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.converter.json.MappingJackson2HttpMessageConverter;
import org.springframework.http.server.ServletServerHttpResponse;
import org.springframework.util.Assert;
import org.springframework.web.context.request.NativeWebRequest;
import org.springframework.web.method.support.HandlerMethodReturnValueHandler;
import org.springframework.web.method.support.ModelAndViewContainer;

import java.io.IOException;
import java.util.List;

/**
 * 处理@ResponseExcel 返回值
 *
 * @author 没秃顶的码农
 */
@Slf4j
@RequiredArgsConstructor
public class ResponseExcelReturnValueHandler implements HandlerMethodReturnValueHandler {

	private final List<SheetWriteHandler> sheetWriteHandlerList;

	private final MappingJackson2HttpMessageConverter errorHttpResponseConverter;


	/**
	 * 只处理@ResponseExcel 声明的方法
	 * @param parameter 方法签名
	 * @return 是否处理
	 */
	@Override
	public boolean supportsReturnType(MethodParameter parameter) {
		return parameter.getMethodAnnotation(ResponseExcel.class) != null;
	}

	/**
	 * 处理逻辑
	 * @param o 返回参数
	 * @param parameter 方法签名
	 * @param mavContainer 上下文容器
	 * @param nativeWebRequest 上下文
	 */
	@Override
	public void handleReturnValue(Object o, MethodParameter parameter, ModelAndViewContainer mavContainer,
			NativeWebRequest nativeWebRequest) {
		/* check */
		HttpServletResponse response = nativeWebRequest.getNativeResponse(HttpServletResponse.class);
		Assert.state(response != null, "No HttpServletResponse");
		ResponseExcel responseExcel = parameter.getMethodAnnotation(ResponseExcel.class);
		Assert.state(responseExcel != null, "No @ResponseExcel");
		mavContainer.setRequestHandled(true);

		if(responseExcel.oss()){
			sheetWriteHandlerList.stream().filter(handler -> handler.support(o)).findFirst()
					.ifPresent(handler -> handler.exportOss(o, response, responseExcel));
			sendResponse(response);
		}else{
			sheetWriteHandlerList.stream().filter(handler -> handler.support(o)).findFirst()
					.ifPresent(handler -> handler.export(o, response, responseExcel));
		}
	}

	private void sendResponse(HttpServletResponse response) {
		ServletServerHttpResponse httpResponse = new ServletServerHttpResponse(response);
		httpResponse.setStatusCode(HttpStatus.OK);

        try {
            errorHttpResponseConverter.write(R.ok(), MediaType.APPLICATION_JSON, httpResponse);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

}
