package com.kxs.common.excel.handler;

import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.converters.Converter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.aliyun.oss.OSS;
import com.kxs.common.excel.annotation.ResponseExcel;
import com.kxs.common.excel.config.ExcelConfigProperties;
import com.kxs.common.excel.config.FileProperties;
import com.kxs.common.excel.enhance.WriterBuilderEnhancer;
import com.kxs.common.excel.http.RemoteSysService;
import com.kxs.common.excel.kit.ExcelException;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.util.CollectionUtils;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import static com.alibaba.excel.EasyExcelFactory.writerSheet;

/**
 * @author 没秃顶的码农
 * @date 2024/07/24
 * <p>
 * 处理单sheet 页面
 */
public class SingleSheetWriteHandler extends AbstractSheetWriteHandler {

    public SingleSheetWriteHandler(ExcelConfigProperties configProperties,
                                   OSS ossClient, FileProperties ossProperties,
                                   ObjectProvider<List<Converter<?>>> converterProvider,
                                   WriterBuilderEnhancer excelWriterBuilderEnhance, RemoteSysService remoteSysService) {
        super(configProperties, ossClient, ossProperties, converterProvider, excelWriterBuilderEnhance, remoteSysService);
    }

    /**
     * obj 是List 且list不为空同时list中的元素不是是List 才返回true
     *
     * @param obj 返回对象
     * @return boolean
     */
    @Override
    public boolean support(Object obj) {
        if (obj instanceof List) {
            List<?> objList = (List<?>) obj;
            return !objList.isEmpty() && !(objList.get(0) instanceof List);
        } else {
            throw new ExcelException("@ResponseExcel 返回值必须为List类型");
        }
    }

    @Override
    public void write(Object obj, HttpServletResponse response, ResponseExcel responseExcel) {
        List<?> eleList = (List<?>) obj;
        ExcelWriter excelWriter = getExcelWriter(response, responseExcel);

        WriteSheet sheet;
        if (CollectionUtils.isEmpty(eleList)) {
            sheet = writerSheet(responseExcel.sheets()[0].sheetName()).build();
        } else {
            // 有模板则不指定sheet名
            Class<?> dataClass = eleList.get(0).getClass();
            sheet = this.sheet(responseExcel.sheets()[0], dataClass, responseExcel.template(),
                    responseExcel.headGenerator());
        }

        // 填充 sheet
        if (responseExcel.fill()) {
            excelWriter.fill(eleList, sheet);
        } else {
            // 写入sheet
            excelWriter.write(eleList, sheet);
        }
        excelWriter.finish();
    }

    @Override
    public FileInputStream writeToOss(Object obj, HttpServletResponse response, ResponseExcel responseExcel) {
        try {
            List<?> eleList = (List<?>) obj;

            // 临时目录 临时文件名
            String tmp = System.getProperty("java.io.tmpdir");
            SimpleDateFormat formatter = new SimpleDateFormat("yyMMddHHmm");
            String times = formatter.format(new Date());
            String fileName = responseExcel.name() + times;
			File file = new File(tmp + fileName + responseExcel.suffix().getValue());
            FileOutputStream fileOutputStream = new FileOutputStream(file);
            ExcelWriter excelWriter = getExcelWriterFile(fileOutputStream, responseExcel);

            WriteSheet sheet;
            if (CollectionUtils.isEmpty(eleList)) {
                sheet = writerSheet(responseExcel.sheets()[0].sheetName()).build();
            } else {
                // 有模板则不指定sheet名
                Class<?> dataClass = eleList.get(0).getClass();
                sheet = this.sheet(responseExcel.sheets()[0], dataClass, responseExcel.template(),
                        responseExcel.headGenerator());
            }


            // 填充 sheet
            if (responseExcel.fill()) {
                excelWriter.fill(eleList, sheet);
            } else {
                // 写入sheet
                excelWriter.write(eleList, sheet);
            }
            excelWriter.finish();
			return new FileInputStream(file);
		} catch (Exception e) {
            throw new RuntimeException(e.getMessage());
        }
    }

}
