package com.kxs.common.pay;

import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.AlipayConfig;
import com.alipay.api.DefaultAlipayClient;
import com.github.binarywang.wxpay.config.WxPayConfig;
import com.github.binarywang.wxpay.service.WxPayService;
import com.github.binarywang.wxpay.service.impl.WxPayServiceImpl;
import com.kxs.common.pay.config.AliPayAccountConfig;
import com.kxs.common.pay.config.WechatPayConfig;
import com.kxs.common.pay.factory.PaymentFactory;
import com.kxs.common.pay.handlers.PayEventHandlers;
import com.kxs.common.pay.service.ali.AliPayService;
import com.kxs.common.pay.service.wechat.WechatPayService;
import com.kxs.common.pay.service.yue.YuePayService;
import lombok.AllArgsConstructor;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

/**
 * 支付配置
 *
 * @author 没秃顶的码农
 * @date 2024-04-24
 */
@Configuration(proxyBeanMethods = false)
@EnableConfigurationProperties({AliPayAccountConfig.class, WechatPayConfig.class})
@AllArgsConstructor
public class PayConfiguration {

    private final WechatPayConfig wechatPayConfig;

    private final AliPayAccountConfig aliPayAccountConfig;

    @Bean
    @Primary
    public WxPayService wxPayClient() {

        WxPayConfig payConfig = new WxPayConfig();
        payConfig.setAppId(wechatPayConfig.getAppId());
        payConfig.setMchId(wechatPayConfig.getMchId());
        payConfig.setApiV3Key(wechatPayConfig.getApiV3Key());
        payConfig.setPrivateKeyPath(wechatPayConfig.getPrivateKeyPath());
        payConfig.setNotifyUrl(wechatPayConfig.getNotifyUrl());
        payConfig.setPrivateCertPath(wechatPayConfig.getPrivateCertPath());
        payConfig.setUseSandboxEnv(false);

        WxPayService wxPayService = new WxPayServiceImpl();
        wxPayService.setConfig(payConfig); //微信配置信息
        return wxPayService;
    }

    @Bean
    @Primary
    public AlipayClient alipayClient() throws AlipayApiException {
        AlipayConfig aliPayConfig = new AlipayConfig();
        aliPayConfig.setAppId(aliPayAccountConfig.getAppId());
        aliPayConfig.setPrivateKey(aliPayAccountConfig.getPrivateKey());
        aliPayConfig.setSignType(aliPayAccountConfig.getSignType());
        aliPayConfig.setAlipayPublicKey(aliPayAccountConfig.getAliPayPublicKey());
        return new DefaultAlipayClient(aliPayConfig);
    }


    @Bean
    @ConditionalOnMissingBean
    public YuePayService yuePayService() {

        return new YuePayService();
    }

    @Bean
    @ConditionalOnMissingBean
    public AliPayService aliPayService(AlipayClient alipayClient) {

        return new AliPayService(alipayClient, aliPayAccountConfig);
    }

    @Bean
    @ConditionalOnMissingBean
    public WechatPayService wxPayService(WxPayService wxPayService) {

        return new WechatPayService(wxPayService);
    }

    @Bean
    @ConditionalOnMissingBean
    public PaymentFactory paymentFactory(AliPayService aliPayService, WechatPayService wxPayService, YuePayService yuePayService) {

        return new PaymentFactory(aliPayService, wxPayService, yuePayService);
    }

    @Bean
    @ConditionalOnMissingBean
    public PayEventHandlers payEventHandlers(PaymentFactory paymentFactory) {

        return new PayEventHandlers(paymentFactory);
    }
}