package com.kxs.common.security.service;

import com.kxs.common.core.constant.SecurityConstants;
import com.kxs.common.core.constant.enums.ErrorTypeEnum;
import com.kxs.common.core.constant.enums.UserStatusEnum;
import com.kxs.common.core.util.R;
import com.kxs.common.core.util.RetOps;
import com.kxs.common.security.model.KxsSecurityUser;
import com.kxs.lhb.basic.api.feign.RemoteLhbBasicService;
import com.kxs.lhb.basic.api.model.LhbUser;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.core.authority.AuthorityUtils;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UsernameNotFoundException;

import java.util.Objects;

/**
 * <p>
 * 继承 oauth2 security实现类登录
 * </p>
 *
 * @author 没秃顶的码农 没秃顶的码农
 */
@Slf4j
@RequiredArgsConstructor
public class WxUserDetailsServiceImpl implements KxsUserDetailsService {

	private final RemoteLhbBasicService remoteLhbUserService;

	@Override
	public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {

		R<LhbUser> result = remoteLhbUserService.loadUserByWxCode(username, SecurityConstants.FROM_IN);
		LhbUser custom = RetOps.of(result)
				.getData()
				.orElseThrow(() -> new UsernameNotFoundException(ErrorTypeEnum.USER_NOT_FOUND.getDescription()));

		if(Objects.equals(custom.getStatus(), UserStatusEnum.REMOVE.getCode())){
			throw new UsernameNotFoundException(ErrorTypeEnum.ACCOUNT_DISABLED.getDescription());
		}
		// 构造security用户
		return new KxsSecurityUser(custom.getId(), custom.getNickname(), SecurityConstants.NOOP,  custom.getWxOpenid(), null,
				true, true, true, !Objects.equals(custom.getLockFlag(), UserStatusEnum.LOCKED.getCode()), AuthorityUtils.NO_AUTHORITIES);

	}

	/**
	 * 是否支持此客户端校验
	 * @param clientId 目标客户端
	 * @param grantType  授权类型
	 * @return true/false
	 */
	@Override
	public boolean support(String clientId, String grantType) {
		return "customer".equals(clientId);
	}

	@Override
	public int getOrder() {
		return Integer.MIN_VALUE + 1;
	}



}
