package com.kxs.common.security.support.wechat;

import com.kxs.common.core.constant.SecurityConstants;
import com.kxs.common.security.support.base.OAuth2ResourceOwnerBaseAuthenticationConverter;
import com.kxs.common.security.util.OAuth2EndpointUtils;
import org.springframework.security.core.Authentication;
import org.springframework.security.oauth2.core.AuthorizationGrantType;
import org.springframework.security.oauth2.core.OAuth2ErrorCodes;
import org.springframework.util.MultiValueMap;
import org.springframework.util.StringUtils;

import java.util.Map;
import java.util.Set;

/**
 * @author 没秃顶的码农
 * @date 2022-05-31
 *
 * 微信登录转换器
 */
public class OAuth2ResourceOwnerWechatAuthenticationConverter
		extends OAuth2ResourceOwnerBaseAuthenticationConverter<OAuth2ResourceOwnerWechatAuthenticationToken> {

	/**
	 * 是否支持此convert
	 * @param grantType 授权类型
	 * @return
	 */
	@Override
	public boolean support(String grantType) {
		return SecurityConstants.WECHAT.equals(grantType);
	}

	@Override
	public OAuth2ResourceOwnerWechatAuthenticationToken buildToken(Authentication clientPrincipal, Set requestedScopes,
			Map additionalParameters) {
		return new OAuth2ResourceOwnerWechatAuthenticationToken(new AuthorizationGrantType(SecurityConstants.WECHAT),
				clientPrincipal, requestedScopes, additionalParameters);
	}

	/**
	 * 校验扩展参数 密码模式密码必须不为空
	 * @param parameters 参数列表
	 */
	@Override
	public void checkParams(MultiValueMap<String, String> parameters) {
//		MultiValueMap<String, String> parameters = OAuth2EndpointUtils.getParameters(request);
		// PHONE (REQUIRED)
		String phone = parameters.getFirst(SecurityConstants.WECHAT_PARAMETER_NAME);
		if (!StringUtils.hasText(phone) || parameters.get(SecurityConstants.WECHAT_PARAMETER_NAME).size() != 1) {
			OAuth2EndpointUtils.throwError(OAuth2ErrorCodes.INVALID_REQUEST, SecurityConstants.WECHAT_PARAMETER_NAME,
					OAuth2EndpointUtils.ACCESS_TOKEN_REQUEST_ERROR_URI);
		}
	}

}
