package com.kxs.common.security.util;

import cn.hutool.core.util.StrUtil;
import com.kxs.common.core.constant.SecurityConstants;
import com.kxs.common.security.model.KxsSecurityUser;
import lombok.experimental.UtilityClass;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * 安全实用程序
 * 安全工具類
 *
 * @author 没秃顶的码农
 * @date 2023/10/28
 */
@UtilityClass
public class SecurityUtils {

	/**
	 * 获取Authentication
	 */
	public Authentication getAuthentication() {
		return SecurityContextHolder.getContext().getAuthentication();
	}

	/**
	 * 获取用户
	 */
	public KxsSecurityUser getUser(Authentication authentication) {
		Object principal = authentication.getPrincipal();
		if (principal instanceof KxsSecurityUser) {
			return (KxsSecurityUser) principal;
		}
		return null;
	}

	/**
	 * 获取用户
	 */
	public KxsSecurityUser getUser() {
		Authentication authentication = getAuthentication();
		if (authentication == null) {
			return null;
		}
		return getUser(authentication);
	}

	/**
	 * 获取用户角色信息
	 * @return 角色集合
	 */
	public List<Long> getRoles() {
		Authentication authentication = getAuthentication();
		Collection<? extends GrantedAuthority> authorities = authentication.getAuthorities();

		List<Long> roleIds = new ArrayList<>();
		authorities.stream()
			.filter(granted -> StrUtil.startWith(granted.getAuthority(), SecurityConstants.ROLE))
			.forEach(granted -> {
				String id = StrUtil.removePrefix(granted.getAuthority(), SecurityConstants.ROLE);
				roleIds.add(Long.parseLong(id));
			});
		return roleIds;
	}

}
