package com.kxs.lhb.basic.api.model;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

import com.baomidou.mybatisplus.annotation.*;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import com.kxs.common.core.valid.Phone;
import jakarta.validation.constraints.NotBlank;

/**
 * 产品表(LhbGoods)表实体类
 *
 * @author 系统
 * @since 2024-10-18 16:10:13
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class LhbGoods extends Model<LhbGoods> implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    
    
    /**
     * 主键ID
     */
    @Schema(description = "主键ID")
    @TableId(type = IdType.AUTO)
    private Integer id;


    /**
     * 新增时间
     */
    @TableField(fill = FieldFill.INSERT)
    @Schema(description = "新增时间")
    private LocalDateTime createTime;


    /**
     * 更新时间
     */
    @TableField(fill = FieldFill.UPDATE)
    @Schema(description = "更新时间")
    private LocalDateTime updateTime;


    /**
     * 删除标记，0未删除，1已删除
     */
    @TableLogic
    @Schema(description = "删除标记，0未删除，1已删除")
    private Integer delFlag;


    /**
     * 版本
     */
    @Schema(description = "版本")
    private Integer version;


    /**
     * 产品名称
     */
    @Schema(description = "产品名称")
    @NotBlank(message = "产品名称不能为空")
    private String goodsName;


    /**
     * 商品封面图
     */
    @Schema(description = "商品封面图")
    @NotBlank(message = "商品封面图不能为空")
    private String picUrl;


    /**
     * 状态 0下架 1上架
     */
    @Schema(description = "状态 0下架 1上架")
    private Integer status;


    /**
     * 月租价格
     */
    @Schema(description = "月租价格")
    @NotNull(message = "月租价格不能为空")
    private BigDecimal price;


    /**
     * 简介
     */
    @Schema(description = "简介")
    private String summary;


    /**
     * 外部产品ID
     */
    @Schema(description = "外部产品ID")
    @NotNull(message = "外部产品ID不能为空")
    private String externalId;


    /**
     * 通道名称
     */
    @Schema(description = "通道名称")
    @NotBlank(message = "通道名称不能为空")
    private String ifCode;


    /**
     * 商品详情
     */
    @Schema(description = "商品详情")
    private String content;


    /**
     * 服务费
     */
    @Schema(description = "服务费")
    private BigDecimal serverFee;


    /**
     * 创建人
     */
    @Schema(description = "创建人")
    @TableField(fill = FieldFill.INSERT)
    private String createBy;


    /**
     * 修改人
     */
    @Schema(description = "修改人")
    @TableField(fill = FieldFill.UPDATE)
    private String updateBy;


    /**
     * 排序
     */
    @Schema(description = "排序")
    private Integer sort;


    /**
     * 办理数量
     */
    @Schema(description = "办理数量")
    private Integer makeCount;


    /**
     * 运营商， 1：电信，2：移动 3 ：联通 4：广电
     */
    @Schema(description = "运营商， 1：电信，2：移动 3 ：联通 4：广电")
    @NotNull(message = "运营商不能为空")
    private Integer operators;


    /**
     * 供应商ID
     */
    @Schema(description = "供应商ID")
    private Integer supplierId;


    /**
     * 年龄区间 18-65
     */
    @Schema(description = "年龄区间 18-65")
    @NotNull(message = "年龄区间不能为空")
    private String ageSection;

}

