package com.kxs.lhb.basic.api.model;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.kxs.common.core.valid.IdCard;
import com.kxs.common.core.valid.group.Insert;
import com.kxs.common.core.valid.group.Update;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import com.kxs.common.core.valid.Phone;
import jakarta.validation.constraints.NotBlank;

/**
 * 订单表(LhbOrder)表实体类
 *
 * @author 系统
 * @since 2024-10-18 16:10:13
 */
@EqualsAndHashCode(callSuper = true)
@Data
public class LhbOrder extends Model<LhbOrder> implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    
    
    /**
     * 主键ID
     */
    @Schema(description = "主键ID")
    @TableId(type = IdType.AUTO)
    @NotNull(groups = Update.class, message = "订单ID不能为空")
    private Integer id;


    /**
     * 新增时间
     */
    @TableField(fill = FieldFill.INSERT)
    @Schema(description = "新增时间")
    private LocalDateTime createTime;


    /**
     * 更新时间
     */
    @TableField(fill = FieldFill.UPDATE)
    @Schema(description = "更新时间")
    private LocalDateTime updateTime;


    /**
     * 删除标记，0未删除，1已删除
     */
    @Schema(description = "删除标记，0未删除，1已删除")
    private Integer delFlag;


    /**
     * 版本
     */
    @Schema(description = "版本")
    private Integer version;


    /**
     * 状态 -1已取消 0待支付 1已支付 2已退款
     */
    @Schema(description = "状态 -1已取消 0待支付 1已支付 2已退款")
    private Integer status;


    /**
     * 用户ID
     */
    @Schema(description = "用户ID")
    private Long userId;


    /**
     * 订单号
     */
    @Schema(description = "订单号")
    private String orderSn;

    /**
     * 商品 ID
     */
    @Schema(description = "商品 ID")
    @NotNull(groups = {Insert.class,Update.class}, message = "商品ID不能为空")
    private Integer goodsId;

    /**
     * SKU ID
     */
    @Schema(description = "SKU ID")
    @NotNull(groups = Update.class, message = "SKU ID不能为空")
    private Integer skuId;


    /**
     * 服务费 单位分
     */
    @Schema(description = "服务费 单位分")
    @NotNull(groups = Update.class, message = "服务费不能为空")
    private BigDecimal serverFee;


    /**
     * 支付时间
     */
    @Schema(description = "支付时间")
    private LocalDateTime payTime;


    /**
     * 办理手机号码
     */
    @Schema(description = "办理手机号码")
    @Phone(groups = {Insert.class, Update.class}, message = "预购手机号码格式错误")
    private String makeMobile;


    /**
     * 支付方式 0微信
     */
    @Schema(description = "支付方式 0微信")
    private Integer payType;


    /**
     * 三方订单号
     */
    @Schema(description = "三方订单号")
    private String outOrderSn;


    /**
     * 套餐名称
     */
    @Schema(description = "套餐名称")
    @NotBlank(groups = Update.class, message = "套餐名称不能为空")
    private String packageName;


    /**
     * 是否首次充值 0-否 1-是
     */
    @Schema(description = "是否首次充值 0-否 1-是")
    private Integer isFirstRecharge;


    /**
     * 三方订单状态 见文档
     */
    @Schema(description = "三方订单状态 见文档")
    private Integer outStatus;


    /**
     * 支付订单号
     */
    @Schema(description = "支付订单号")
    private String payTradeNo;


    /**
     * 退款订单号
     */
    @Schema(description = "退款订单号")
    private String refundTradeNo;


    /**
     * 备注
     */
    @Schema(description = "备注")
    private String remark;


    /**
     * 退款金额 单位分
     */
    @Schema(description = "退款金额 单位分")
    private BigDecimal refundPrice;


    /**
     * 操作人
     */
    @TableField(fill = FieldFill.INSERT)
    @Schema(description = "操作人")
    private String createBy;


    /**
     * 服务商号
     */
    @Schema(description = "服务商号")
    @NotBlank(groups = Insert.class, message = "服务商号不能为空")
    private String isvNo;


    /**
     * 操作人
     */
    @Schema(description = "操作人")
    @TableField(fill = FieldFill.UPDATE)
    private String updateBy;


    /**
     * 通道名称
     */
    @Schema(description = "通道名称")
    private String ifCode;


    /**
     * 客户姓名
     */
    @Schema(description = "客户姓名")
    @NotBlank(message = "客户姓名不能为空")
    private String custName;


    /**
     * 身份证号
     */
    @Schema(description = "身份证号")
    @IdCard(groups = Insert.class)
    private String idCard;


    /**
     * 收货人手机号码
     */
    @Schema(description = "收货人手机号码")
    @Phone(groups = Update.class)
    private String contMobile;


    /**
     * 地市编码
     */
    @Schema(description = "地市编码")
    @NotBlank(groups = {Insert.class, Update.class}, message = "地市编码不能为空")
    private String regionId;


    /**
     * 收货省市县编码，用英文逗号分割
     */
    @Schema(description = "收货省市县编码，用英文逗号分割")
    @NotBlank(groups = Update.class, message = "收货省市县编码不能为空")
    private String area;


    /**
     * 收货人详细地址 精确到门牌号
     */
    @Schema(description = "收货人详细地址 精确到门牌号")
    @NotBlank(groups = Update.class, message = "收货人详细地址不能为空")
    private String address;


    /**
     * 工号
     */
    @Schema(description = "工号")
    @NotBlank(groups = Insert.class, message = "工号不能为空")
    private String employNum;


    /**
     * 运营商， 1：电信，2：移动 3 ：联通 4：广电
     */
    @Schema(description = "运营商， 1：电信，2：移动 3 ：联通 4：广电")
    private Integer operators;


    /**
     * 是否激活 1激活
     */
    @Schema(description = "是否激活 1激活")
    private Integer isAct;

    /**
     * 快递单号
     */
    @Schema(description = "快递单号")
    private String expressNo;

    /**
     * 首充金额
     */
    @Schema(description = "首充金额")
    private BigDecimal firstCharge;

}

