package com.kxs.lhb.basic.api.util;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.LocalDateTimeUtil;
import com.google.common.collect.Lists;

import java.time.LocalDate;
import java.util.Collections;
import java.util.List;

/**
 * 仓库模块 日期操作
 *
 * @author 没秃顶的码农
 * @date 2024-01-11
 */
public class TotalDateUtil {

    /**
     * 获取日期 格式 20240110
     *
     * @return {@link String}
     */
    public static Integer getDateNumber(LocalDate date){

        return Integer.valueOf(LocalDateTimeUtil.format(date, DatePattern.PURE_DATE_PATTERN));
    }

    /**
     * 获取月份 格式 202401
     *
     * @return {@link String}
     */
    public static Integer getMonthNumber(LocalDate date){

        return Integer.valueOf(LocalDateTimeUtil.format(date, DatePattern.SIMPLE_MONTH_PATTERN));
    }

    /**
     * 获取过去某几个的月份列表
     *
     * @param date 日期
     * @return {@link Integer}
     */
    public static List<Integer> getMonthList(LocalDate date, Integer num){

        List<Integer> times = Lists.newArrayList();
        for (int i = 0; i < num; i++) {
            // 计算过去半年每月月份
            LocalDate currentDay = date.minusMonths(i);

            times.add(getMonthNumber(currentDay));
        }
        return times;
    }

    /**
     * 获取过去某几天的日列表
     *
     * @param date 日期
     * @return {@link List}<{@link Integer}>
     */
    public static List<Integer> getDayList(LocalDate date, Integer num){

        List<Integer> times = Lists.newArrayList();

        for (int i = 0; i < num; i++) {
            // 计算每一天的日期
            LocalDate currentDay = date.minusDays(i);
            //获取当前日的月份值
            times.add(getDateNumber(currentDay));
        }
        return times;
    }

    /**
     * 获取月份的天列表
     * 如果为当月则只取历史的天数
     *
     * @param month 月
     * @return {@link List}<{@link Integer}>
     */
    public static List<Integer> getMonthDayList(String month){

        List<Integer> times = Lists.newArrayList();

        LocalDate parse = LocalDateTimeUtil.parseDate(month, DatePattern.SIMPLE_MONTH_PATTERN);

        LocalDate localDate = LocalDate.now();
        //本月
        if(parse.getMonth() == localDate.getMonth()){
            LocalDate firstDayOfMonth = localDate.withDayOfMonth(1);
            for (LocalDate date = firstDayOfMonth; !date.isAfter(localDate); date = date.plusDays(1)) {
                times.add(Integer.valueOf(date.format(DatePattern.PURE_DATE_FORMATTER)));
            }
        }else{
            int daysInMonth = parse.lengthOfMonth();
            for (int day = 1; day <= daysInMonth; day++) {
                LocalDate date = parse.withDayOfMonth(day);
                times.add(Integer.valueOf(date.format(DatePattern.PURE_DATE_FORMATTER)));
            }
        }
        Collections.reverse(times);
        return times;
    }

}
