package com.kxs.lhb.basic.biz.channel.factory;

import cn.hutool.extra.spring.SpringUtil;
import com.kxs.common.core.exception.GlobalCustomerException;
import com.kxs.lhb.basic.api.constant.enums.ChannelCodeEnum;
import com.kxs.lhb.basic.biz.channel.BasicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.Ordered;
import org.springframework.stereotype.Service;

import java.util.Comparator;
import java.util.Map;
import java.util.Optional;

/**
 * 通道工厂
 *
 * @author 没秃顶的码农
 * @date 2024-10-25
 */
@Service
@Slf4j
public class ChannelFactory {


    public BasicService getChannel(String ifCode) {

        Map<String, BasicService> basicServiceMap = SpringUtil.getBeansOfType(BasicService.class);

        ChannelCodeEnum channelCode = ChannelCodeEnum.getChannelCode(ifCode);
        if (channelCode == null) {
            log.error("未找到对应通道{}", ifCode);
            throw new GlobalCustomerException("未找到对应通道");
        }
        Optional<BasicService> optional = basicServiceMap.values()
                .stream()
                .filter(service -> service.support(channelCode))
                .max(Comparator.comparingInt(Ordered::getOrder));
        if (optional.isEmpty()) {
            log.error("未找到对应通道{}处理类", channelCode.getDescription());
            throw new GlobalCustomerException("未找到对应通道处理类");
        }
        return optional.get();
    }

}
