package com.kxs.lhb.basic.biz.channel.tongyi;


import cn.hutool.core.lang.TypeReference;
import cn.hutool.core.util.IdUtil;
import cn.hutool.crypto.digest.DigestUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.kxs.common.core.exception.GlobalCustomerException;
import com.kxs.lhb.basic.api.dto.tongyi.BasicReq;
import com.kxs.lhb.basic.api.dto.tongyi.TyCommonReq;
import com.kxs.lhb.basic.api.vo.tongyi.TyCommRes;
import lombok.extern.slf4j.Slf4j;

/**
 * tong yi 基础服务
 *
 * @author 没秃顶的码农
 * @date 2024-10-18
 */
@Slf4j
public abstract class TongYiService {

    private static final String APP_KEY = "6sojqlem7zf5jq33s0i90bln2a0nx106";
    private static final String APP_SECRET = "ascqhimf4v0qyfg7bnqep1e6elg5343g";
    private static final String APPID = "1847154180683214850";


    private static final  String GATEWAY = "http://183.213.19.250:11043/api";

    protected <T> TyCommRes<T> sendToUrl(TyCommonReq param, String url){

        param.setRequestId(IdUtil.simpleUUID());

        BasicReq req = buildSign(param);

        log.info("发送请求到tong yi平台，请求参数：{}, 请求URL：{}", JSONUtil.toJsonStr(req), url);
        String response = HttpRequest.post(GATEWAY + url)
                .body(JSONUtil.toJsonStr(req))
                .timeout(100000)
                .execute().body();

        log.info("tong yi地址{}， Response:\n{}", url, response);

        if (response == null || !JSONUtil.isTypeJSON(response)) {
            log.error("响应报文非有效格式{}", response);
            throw new GlobalCustomerException("响应报文非有效格式" + response);
        }

        TyCommRes<T> res = JSONUtil.toBean(response, new TypeReference<>() {}, true);
        if(res.getCode() != 200){
            throw new GlobalCustomerException("返回错误信息" + res.getMsg());
        }

        return res;
    }

    private BasicReq buildSign(TyCommonReq param){

        BasicReq<Object> req = new BasicReq<>();
        req.setBody(param);
        req.setAppId(APPID);
        req.setTimestamp(String.valueOf(System.currentTimeMillis()));
        req.setSign(DigestUtil.md5Hex(APP_KEY + ":" + APP_SECRET + ":" + req.getTimestamp()));

        return req;
    }
}
