package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.lhb.basic.api.model.LhbBanner;
import com.kxs.lhb.basic.biz.service.LhbBannerService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 广告管理(SysBanner)控制层
 *
 * @author 系统
 * @since 2024-10-18 16:10:15
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysBanner")
@Tag(description = "sysBanner", name = "SysBanner")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysBannerController {

    /**
     * 服务对象
     */
    private final LhbBannerService lhbBannerService;



    /**
     * 列表
     * @param page 分页对象
     * @return 列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbBanner> page, @ParameterObject LhbBanner param) {

        return R.ok(lhbBannerService.page(page, Wrappers.query(param)));
    }


    /**
     * 删除
     * Integer id 主键ID
     * @return 删除
     */
    @SysLog("首页广告管理表删除")
    @DeleteMapping("/removeById/{id}")
    @PreAuthorize("@pms.hasPermission('lhb_banner_removeById')")
    public R removeById(@PathVariable Integer id) {

        return R.ok(lhbBannerService.removeById(id));
    }


    /**
     * 新增/修改
     * @return 新增/修改
     */
    @SysLog("首页广告管理表新增")
    @PostMapping("/addOrUpdate")
    @PreAuthorize("@pms.hasPermission('lhb_banner_addOrUpdate')")
    public R addOrUpdate(@RequestBody LhbBanner param) {

        return R.ok(lhbBannerService.saveOrUpdate(param));
    }


    /**
     * 详情
     * @return 详情
     */
    @GetMapping("/detail")
    public R detail(@RequestParam("id") Integer id) {

        return R.ok(lhbBannerService.getById(id));
    }





}

