package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.lhb.basic.api.model.LhbCol;
import com.kxs.lhb.basic.biz.service.LhbColService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 广告管理(SysCol)控制层
 *
 * @author 系统
 * @since 2024-10-18 16:10:15
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysCol")
@Tag(description = "sysCol", name = "SysCol")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysColController {

    /**
     * 服务对象
     */
    private final LhbColService lhbColService;



    /**
     * 广告管理-分类列表
     *
     * @param page 分页对象
     * @return 广告管理-分类列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbCol> page, @ParameterObject LhbCol param) {

        return R.ok(lhbColService.page(page, Wrappers.query(param)));
    }


    /**
     * 广告管理-分类新增/修改
     *
     * @return 广告管理-分类新增/修改
     */
    @SysLog("广告管理-分类新增/修改")
    @PostMapping("/addOrUpdate")
    @PreAuthorize("@pms.hasPermission('lhb_col_addOrUpdate')")
    public R addOrUpdate(@RequestBody LhbCol kxsCol) {

        return R.ok(lhbColService.saveOrUpdate(kxsCol));
    }


    /**
     * 广告管理-分类删除
     *
     * @return 广告管理-分类删除
     */
    @SysLog("广告管理-分类删除")
    @DeleteMapping("/removeById/{id}")
    @PreAuthorize("@pms.hasPermission('lhb_col_delete')")
    public R removeById(@PathVariable("id") Integer id) {

        return R.ok(lhbColService.removeById(id));
    }




}

