package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.common.security.annotation.Inner;
import com.kxs.lhb.basic.api.model.LhbGoods;
import com.kxs.lhb.basic.biz.service.LhbGoodsService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 套餐管理(SysGoods)控制层
 *
 * @author 系统
 * @since 2024-10-21 11:42:55
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysGoods")
@Tag(description = "sysGoods", name = "SysGoods")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysGoodsController {

    /**
     * 服务对象
     */
    private final LhbGoodsService lhbGoodsService;



    /**
     * 列表
     *
     * @param page 分页对象
     * @RequestParam param 实体参数
     * @return 列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbGoods> page, @ParameterObject LhbGoods param) {

        return R.ok(lhbGoodsService.page(page, Wrappers.lambdaQuery(param).orderByDesc(LhbGoods::getId)));
    }

    /**
     * 获取第三方通道所有商品列表
     *
     * @param ifCode if 代码
     * @return {@link R }
     */
    @GetMapping("/getOutGoods")
    public R getOutGoods(@RequestParam("ifCode") String ifCode) {

        return R.ok(lhbGoodsService.getOutGoods(ifCode));
    }


    /**
     * 新增
     *
     * @RequestBody param 实体参数
     * @return 新增
     */
    @SysLog("产品表新增")
    @PostMapping("/add")
    @PreAuthorize("@pms.hasPermission('lhb_goods_add')")
    public R add(@RequestBody LhbGoods param) {

        return R.ok(lhbGoodsService.addGoods(param));
    }


    /**
     * 修改
     *
     * @RequestBody param 实体参数
     * @return 修改
     */
    @SysLog("产品表修改")
    @PutMapping("/update")
    @PreAuthorize("@pms.hasPermission('lhb_goods_update')")
    public R update(@RequestBody LhbGoods param) {

        return R.ok(lhbGoodsService.updateGoods(param));
    }


    /**
     * 删除
     *
     * Integer id 主键ID
     * @return 删除
     */
    @SysLog("产品表删除")
    @DeleteMapping("/removeById/{id}")
    @PreAuthorize("@pms.hasPermission('lhb_goods_removeById')")
    public R removeById(@PathVariable Integer id) {

        return R.ok(lhbGoodsService.removeByGoodsId(id));
    }

    /**
     * 更新商品信息
     */
    @Inner(value = false)
    @GetMapping("/goodsInfoTask")
    public void goodsInfoTask() {

        lhbGoodsService.goodsInfoTask();
    }



}

