package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.lhb.basic.api.model.LhbIsvInfo;
import com.kxs.lhb.basic.biz.service.LhbIsvInfoService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 服务商(SysIsvInfo)控制层
 *
 * @author 系统
 * @since 2024-10-18 16:10:15
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysIsvInfo")
@Tag(description = "sysIsvInfo", name = "SysIsvInfo")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysIsvInfoController {

    /**
     * 服务对象
     */
    private final LhbIsvInfoService lhbIsvInfoService;



    /**
     * 列表
     *
     * @param page 分页对象
     * @return 列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbIsvInfo> page, @ParameterObject LhbIsvInfo param) {

        return R.ok(lhbIsvInfoService.page(page, Wrappers.query(param)));
    }


    /**
     * 详情
     *
     * param 实体参数
     * @return 详情
     */
    @GetMapping("/detail")
    public R detail(@RequestParam("id") Integer id) {

        return R.ok(lhbIsvInfoService.getById(id));
    }


    /**
     * 添加
     *
     * @RequestBody param 实体参数
     * @return 添加
     */
    @SysLog("服务商新增")
    @PostMapping("/add")
    @PreAuthorize("@pms.hasPermission('sys_isv_add')")
    public R add(@Valid @RequestBody LhbIsvInfo param) {

        return R.ok(lhbIsvInfoService.save(param));
    }


    /**
     * 修改
     *
     * @RequestBody param 实体参数
     * @return 修改
     */
    @SysLog("服务商修改")
    @PutMapping("/update")
    @PreAuthorize("@pms.hasPermission('sys_isv_edit')")
    public R update(@RequestBody LhbIsvInfo param) {

        return R.ok(lhbIsvInfoService.updateById(param));
    }


    /**
     * 删除
     *
     * Integer id 主键ID
     * @return 删除
     */
    @SysLog("服务商删除")
    @DeleteMapping("/removeById/{id}")
    @PreAuthorize("@pms.hasPermission('sys_isv_delete')")
    public R removeById(@PathVariable Integer id) {
        return R.ok(lhbIsvInfoService.removeById(id));
    }





}

