package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.idempotent.annotation.Idempotent;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.common.security.annotation.Inner;
import com.kxs.lhb.basic.api.constant.enums.OrderStatusEnum;
import com.kxs.lhb.basic.api.model.LhbOrder;
import com.kxs.lhb.basic.biz.service.LhbOrderService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 订单管理(SysOrder)控制层
 *
 * @author 系统
 * @since 2024-10-21 11:42:55
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysOrder")
@Tag(description = "sysOrder", name = "SysOrder")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysOrderController {

    /**
     * 服务对象
     */
    private final LhbOrderService lhbOrderService;



    /**
     * 列表
     *
     * @param page 分页对象
     * @RequestParam param 实体参数
     * @return 列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbOrder> page, @ParameterObject LhbOrder param) {
        return R.ok(lhbOrderService.page(page, Wrappers.lambdaQuery(param).orderByDesc(LhbOrder::getId)));
    }


    /**
     * 取消订单
     *
     * @RequestBody param 实体参数
     * @return 取消订单
     */
    @SysLog("订单表修改")
    @PutMapping("/cancelOrder")
    @PreAuthorize("@pms.hasPermission('lhb_order_cancelOrder')")
    @Idempotent
    public R cancelOrder(@RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.cancelOrder(param));
    }


    /**
     * 服务费退还
     *
     * @RequestBody param 实体参数
     * @return 服务费退还
     */
    @SysLog("订单表修改")
    @PutMapping("/refundFee")
    @PreAuthorize("@pms.hasPermission('lhb_order_refundFee')")
    @Idempotent
    public R refundFee(@RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.refundFee(param));
    }


    /**
     * 物流轨迹
     *
     * @RequestParam param 实体参数
     * @return 物流轨迹
     */
    @GetMapping("/queryLogistics")
    public R queryLogistics(@RequestParam("id") Integer id) {

        return R.ok(lhbOrderService.queryLogistics(id));
    }


    /**
     * 服务费退还记录
     *
     * @param page 分页对象
     * @RequestParam param 实体参数
     * @return 服务费退还记录
     */
    @GetMapping("/refundPage")
    public R refundPage(@ParameterObject Page<LhbOrder> page, @ParameterObject LhbOrder param) {

        param.setStatus(OrderStatusEnum.REFUND.getCode());
        return R.ok(lhbOrderService.page(page, Wrappers.lambdaQuery(param).orderByDesc(LhbOrder::getId)));
    }


    /**
     * 更新订单状态
     */
    @Inner(value = false)
    @GetMapping("/orderStatusTask")
    public void orderStatusTask() {

        lhbOrderService.orderStatusTask();
    }

    /**
     * 查询订单是否首冲
     */
    @Inner(value = false)
    @GetMapping("/orderFirstCharge")
    public void orderFirstCharge() {

        lhbOrderService.orderFirstCharge();
    }


}

