package com.kxs.lhb.basic.biz.controller.admin;

import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.kxs.common.core.util.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.excel.annotation.RequestExcel;
import com.kxs.common.idempotent.annotation.Idempotent;
import com.kxs.lhb.basic.api.model.LhbOrderRecharge;
import com.kxs.lhb.basic.api.vo.admin.bill.BillExcelVO;
import org.springdoc.core.annotations.ParameterObject;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import com.kxs.lhb.basic.biz.service.LhbOrderRechargeService;

import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpHeaders;

import lombok.RequiredArgsConstructor;

import java.util.List;

/**
 * 充值记录(SysRecharge)控制层
 *
 * @author 系统
 * @since 2024-10-21 11:42:55
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysRecharge")
@Tag(description = "sysRecharge", name = "SysRecharge")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysRechargeController {

    /**
     * 服务对象
     */
    private final LhbOrderRechargeService lhbOrderRechargeService;



    /**
     * 列表
     *
     * @param page 分页对象
     * @RequestParam param 实体参数
     * @return 列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbOrderRecharge> page, @ParameterObject LhbOrderRecharge param) {

        return R.ok(lhbOrderRechargeService.page(page, Wrappers.lambdaQuery(param).orderByDesc(LhbOrderRecharge::getCreateTime)));
    }


    /**
     * 导入账单
     *
     * @param billExcelList Bill Excel 列表
     * @param bindingResult 绑定结果
     * @return {@link R }
     */
    @PostMapping("/import")
    public R importBill(@RequestExcel(ignoreEmptyRow = true) List<BillExcelVO> billExcelList, BindingResult bindingResult) {

        //进度条key
        String uuid = IdUtil.simpleUUID();
        lhbOrderRechargeService.importBill(billExcelList, uuid, bindingResult);
        return R.ok(uuid);
    }





}

