package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.lhb.basic.api.model.LhbRulemaking;
import com.kxs.lhb.basic.biz.service.LhbRulemakingService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 协议规则表(SysRuleMaking)控制层
 *
 * @author 系统
 * @since 2024-10-18 16:10:15
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysRuleMaking")
@Tag(description = "sysRuleMaking", name = "SysRuleMaking")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysRuleMakingController {

    /**
     * 服务对象
     */
    private final LhbRulemakingService lhbRulemakingService;




    /**
     * 协议管理-列表
     *
     * @param page 分页对象
     * @return 协议管理-列表
     */
    @GetMapping("/page")
    public R ruleMakingPage(Page<LhbRulemaking> page, LhbRulemaking param) {

        return R.ok(lhbRulemakingService.page(page,Wrappers.query(param)));
    }


    /**
     * 协议管理-新增或修改
     *
     * @return 协议管理-新增或修改
     */
    @PostMapping("/addOrUpdate")
    @PreAuthorize("@pms.hasPermission('lhb_rulemaking_addOrUpdate')")
    public R addOrUpdate(@RequestBody LhbRulemaking param) {
        return R.ok(lhbRulemakingService.saveOrUpdate(param));
    }


    /**
     * 协议管理-删除
     *
     * @return 协议管理-删除
     */
    @DeleteMapping("/removeById/{id}")
    @PreAuthorize("@pms.hasPermission('lhb_rulemaking_removeById')")
    public R removeById(@PathVariable("id") Integer id) {
        return R.ok(lhbRulemakingService.removeById(id));
    }






}

