package com.kxs.lhb.basic.biz.controller.admin;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.lhb.basic.api.model.LhbSupplier;
import com.kxs.lhb.basic.biz.service.LhbSupplierService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 供应商(SysSupplier)控制层
 *
 * @author 系统
 * @since 2024-10-18 16:10:15
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("sysSupplier")
@Tag(description = "sysSupplier", name = "SysSupplier")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysSupplierController {

    /**
     * 服务对象
     */
    private final LhbSupplierService lhbSupplierService;



    /**
     * 列表
     *
     * @param page 分页对象
     * @return 列表
     */
    @GetMapping("/page")
    public R page(@ParameterObject Page<LhbSupplier> page, @ParameterObject LhbSupplier param) {

        return R.ok(lhbSupplierService.page(page, Wrappers.query(param)));
    }


    /**
     * 添加
     *
     * @RequestBody param 实体参数
     * @return 添加
     */
    @SysLog("新增供应商")
    @PostMapping("/addOrUpdate")
    @PreAuthorize("@pms.hasPermission('lhb_supplier_addOrUpdate')")
    public R addOrUpdate(@Valid @RequestBody LhbSupplier param) {

        return R.ok(lhbSupplierService.saveOrUpdate(param));
    }



    /**
     * 删除
     * Integer id 主键ID
     * @return 删除
     */
    @SysLog("删除供应商")
    @DeleteMapping("/removeById/{id}")
    @PreAuthorize("@pms.hasPermission('lhb_supplier_removeById')")
    public R removeById(@PathVariable Integer id) {

        return R.ok(lhbSupplierService.removeById(id));
    }




}

