package com.kxs.lhb.basic.biz.controller.cusmoter;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.kxs.common.core.util.R;
import com.kxs.lhb.basic.api.model.LhbArea;
import com.kxs.lhb.basic.biz.service.LhbAreaService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 地区管理(Area)控制层
 *
 * @author 系统
 * @since 2024-10-22 14:41:49
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("area")
@Tag(description = "area", name = "Area")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class AreaController {

    /**
     * 服务对象
     */
    private final LhbAreaService lhbAreaService;



    /**
     * 获取城市编码
     *
     * @RequestParam param 实体参数
     * @return 获取城市编码
     */
    @GetMapping("/getAreaCode")
    public R getAreaCode(@ParameterObject LhbArea param) {

        LambdaQueryWrapper<LhbArea> query = Wrappers.lambdaQuery(LhbArea.class);
        if(StrUtil.isNotBlank(param.getAreaName())){
            query.like(LhbArea::getAreaName, param.getAreaName());
        }
        return R.ok(lhbAreaService.getOne(query.last("limit 1")));
    }


    /**
     * 获取省市区
     *
     * @RequestParam param 实体参数
     * @return 获取省市区
     */
    @GetMapping("/getArea")
    public R getArea(@ParameterObject LhbArea param) {

        LambdaQueryWrapper<LhbArea> query = Wrappers.lambdaQuery(LhbArea.class);
        if(StrUtil.isNotBlank(param.getParentId())){
            query.eq(LhbArea::getParentId, param.getParentId());
        }else{
            query.isNull(LhbArea::getParentId);
        }
        return R.ok(lhbAreaService.list(query));
    }





}

