package com.kxs.lhb.basic.biz.controller.cusmoter;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.core.util.R;
import com.kxs.lhb.basic.api.dto.cusmoter.goods.NumbersDTO;
import com.kxs.lhb.basic.api.model.LhbGoods;
import com.kxs.lhb.basic.biz.service.LhbAreaService;
import com.kxs.lhb.basic.biz.service.LhbGoodsService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商品管理(Goods)控制层
 *
 * @author 系统
 * @since 2024-10-22 14:41:49
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("goods")
@Tag(description = "goods", name = "Goods")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class GoodsController {

    /**
     * 服务对象
     */
    private final LhbGoodsService lhbGoodsService;
    private final LhbAreaService lhbAreaService;



    /**
     * 商品列表
     *
     * @param page 分页对象
     * @return 商品列表
     */
    @GetMapping("/getGoodsList")
    public R getGoodsList(@ParameterObject Page<LhbGoods> page) {

        return R.ok(lhbGoodsService.page(page, Wrappers.lambdaQuery(LhbGoods.class)
                        .eq(LhbGoods::getStatus, CommonConstants.SUCCESS)
                .orderByAsc(LhbGoods::getSort)));
    }


    /**
     * 详情
     *
     * @RequestParam param 实体参数
     * @return 详情
     */
    @GetMapping("/detail")
    public R detail(@RequestParam("id") Integer id) {

        return R.ok(lhbGoodsService.detail(id));
    }


    /**
     * 选号
     *
     * @RequestParam param 实体参数
     * @return 选号
     */
    @GetMapping("/numbers")
    public R numbers(@Validated @ParameterObject NumbersDTO param) {

        return R.ok(lhbGoodsService.getNumbers(param));
    }





}

