package com.kxs.lhb.basic.biz.controller.cusmoter;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.LocalDateTimeUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yulichang.toolkit.JoinWrappers;
import com.kxs.common.core.util.R;
import com.kxs.common.core.valid.group.Insert;
import com.kxs.common.core.valid.group.Update;
import com.kxs.common.idempotent.annotation.Idempotent;
import com.kxs.common.security.util.SecurityUtils;
import com.kxs.lhb.basic.api.model.LhbGoodsSku;
import com.kxs.lhb.basic.api.model.LhbOrder;
import com.kxs.lhb.basic.api.vo.cusmoter.order.MyOrderVO;
import com.kxs.lhb.basic.biz.service.LhbOrderService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 订单管理(Order)控制层
 *
 * @author 系统
 * @since 2024-10-22 14:41:49
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("order")
@Tag(description = "order", name = "Order")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class OrderController {

    /**
     * 服务对象
     */
    private final LhbOrderService lhbOrderService;


    /**
     * 预占号码
     *
     * @return 下单
     * @RequestBody param 实体参数
     */
    @Idempotent(expireTime = 30, info = "号码已经被申请")
    @PostMapping("/prePhone")
    public R prePhone(@Validated({Insert.class}) @RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.prePhone(param));
    }


    /**
     * 下单
     *
     * @return 下单
     * @RequestBody param 实体参数
     */
    @Idempotent(key = "#makeMobile", expireTime = 15, info = "操作频繁，15秒后重试")
    @PostMapping("/submit")
    public R submit(@Validated({Update.class}) @RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.submit(param));
    }


    /**
     * 我的订单
     *
     * @param page 分页对象
     * @return 我的订单
     */
    @GetMapping("/myOrder")
    public R myOrder(@ParameterObject Page<MyOrderVO> page) {

        return R.ok(lhbOrderService.selectJoinListPage(page, MyOrderVO.class, JoinWrappers.lambda(LhbOrder.class)
                        .selectAsClass(LhbOrder.class, MyOrderVO.class)
                        .leftJoin(LhbGoodsSku.class,  LhbGoodsSku::getId, LhbOrder::getSkuId)
                        .selectAs(LhbGoodsSku::getMonthFee, MyOrderVO::getMonthFee)
                        .eq(LhbOrder::getUserId, SecurityUtils.getUser().getId())
                .orderByDesc(LhbOrder::getId)));
    }


    /**
     * 查看物流信息
     *
     * @return 查看物流信息
     * @RequestParam param 实体参数
     */
    @GetMapping("/queryLogistics")
    public R queryLogistics(@RequestParam("id") Integer id) {

        return R.ok(lhbOrderService.queryLogistics(id));
    }


    /**
     * 发起支付
     *
     * @return 发起支付
     * @RequestBody param 实体参数
     */
    @PostMapping("/payOrder")
    public R payOrder(@RequestBody LhbOrder param) {

        return R.ok(lhbOrderService.payOrder(param));
    }


}

