package com.kxs.lhb.basic.biz.handlers;

import com.github.binarywang.wxpay.bean.notify.WxPayNotifyV3Response;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.pay.enums.PayPlatformEnum;
import com.kxs.common.pay.handlers.PayMessageHandler;
import com.kxs.common.pay.model.WxPayMessage;
import com.kxs.common.pay.service.wechat.WechatPayService;
import com.kxs.lhb.basic.biz.service.LhbOrderService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;


/**
 * 支付宝支付回调处理器
 * @author mac
 */
@Component
@Slf4j
@RequiredArgsConstructor
public class WxPayMessageHandler implements PayMessageHandler<WxPayMessage, WechatPayService> {

    private final LhbOrderService orderService;

    /**
     * 处理支付回调消息的处理器接口
     *
     * @param payMessage 支付消息
     * @param payService 支付服务
     * @return xml, text格式的消息，如果在异步规则里处理的话，可以返回null
     */
    @Override
    public String handle(WxPayMessage payMessage, WechatPayService payService) {
        log.info("微信支付回调消息处理，订单号：{}", payMessage.getOutTradeNo());

        //套餐订单处理
        if (payMessage.getAttach().equals(CommonConstants.PRODUCT_FLAG)) {

            orderService.payBack(payMessage.getOutTradeNo(), payMessage.getTransactionId());
        }
        return WxPayNotifyV3Response.success("处理成功");
    }

    @Override
    public boolean support(PayPlatformEnum payPlatformEnum) {
        return PayPlatformEnum.WX.equals(payPlatformEnum);
    }

    @Override
    public int getOrder() {
        return Integer.MIN_VALUE + 1;
    }
}
