package com.kxs.lhb.basic.biz.mq;

import com.alibaba.fastjson.JSON;
import com.kxs.common.pay.factory.PaymentFactory;
import com.kxs.lhb.basic.api.amqp.RabbitOrderTimeoutQueueMQ;
import com.kxs.lhb.basic.api.constant.enums.OrderStatusEnum;
import com.kxs.lhb.basic.api.model.LhbOrder;
import com.kxs.lhb.basic.biz.service.LhbOrderService;
import com.rabbitmq.client.Channel;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * rabbit 队列侦听器 商品下单过期队列
 *
 * @author Pota1ovO
 * @date 2024-05-07
 */
@Component
@Slf4j
@RequiredArgsConstructor
public class RabbitOrderTimeoutQueueListener {

	private final LhbOrderService orderService;

	private final PaymentFactory paymentFactory;

	/**
	 * 监听 商品下单过期 队列的处理器
	 *
	 * @param message 消息
	 */
	@RabbitListener(queues = RabbitOrderTimeoutQueueMQ.QUEUE_NAME, ackMode = "MANUAL")
	@RabbitHandler
	public void onMessage(String msg, Message message, Channel channel){
		log.info("商品下单过期队列: " + RabbitOrderTimeoutQueueMQ.parse(msg));
        try {
			RabbitOrderTimeoutQueueMQ.MsgEntity parse = RabbitOrderTimeoutQueueMQ.parse(msg);
			Integer id = parse.getOrderId();
			//根据订单号查询该订单是否付款成功,如果仍未付款成功,关闭订单
			LhbOrder order = orderService.getById(id);
			if (order != null && order.getStatus().equals(OrderStatusEnum.NO_PAY.getCode())){
				orderService.changeTimeoutOrder(order);
			}
			channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
        } catch (Exception e) {
			log.error("商品下单过期队列消费失败:{}", JSON.toJSONString(msg), e);
			try {
				channel.basicReject(message.getMessageProperties().getDeliveryTag(), false);
			} catch (IOException ex) {
				log.error("商品下单过期进入死信队列失败" + ex.getMessage(), ex);
			}
        }
    }
}