package com.kxs.lhb.basic.biz.mq.model;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.kxs.lhb.basic.api.model.LhbNotify;
import com.kxs.lhb.basic.api.util.RsaUtil;
import com.kxs.lhb.system.api.util.ParamResolver;
import lombok.Data;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;

/**
 * 营销端统一请求
 *
 * @author 没秃顶的码农
 * @date 2024-09-02
 */
@Slf4j
@Data
public class MarkingModel {



    public static MarkingModelBuilder builder() {
        return new MarkingModelBuilder();
    }

    /**
     * 标记模型生成器
     *
     * @author 没秃顶的码农
     * @date 2024-09-02
     */
    public static class MarkingModelBuilder {

        private CommMarking markingModel;

        public MarkingModelBuilder content(LhbNotify notify) {

            this.markingModel = new CommMarking();
            this.markingModel.setContent(JSONUtil.toJsonStr(notify.getParams()));
            this.markingModel.setNoticeId(notify.getNotifyId());
            this.markingModel.setTimestamp(String.valueOf(System.currentTimeMillis()));
            this.markingModel.setIsvNo(notify.getIsvNo());

            return this;
        }

        @SneakyThrows
        public MarkingModelBuilder sign(String privateKey) {
            String signStr = "timestamp=" + markingModel.getTimestamp()
                    + "&noticeId=" + markingModel.getNoticeId()
                    +  "&isvNo=" + markingModel.getIsvNo()
                    +  "&content=" + markingModel.getContent();
            this.markingModel.setSign(RsaUtil.sign(privateKey, signStr));
            return this;
        }

        @SneakyThrows
        public MarkingModelBuilder encrypt(String publicKey) {

            this.markingModel.setContent(RsaUtil.encrypt(publicKey, markingModel.getContent()));

            return this;
        }

        public boolean execute(String url) {

            log.info("Marking Request: {}", JSONUtil.toJsonStr(markingModel));
            String response = HttpRequest.post(url)
                    .body(JSONUtil.toJsonStr(markingModel))
                    .execute().body();
            if (StrUtil.isEmpty(response) || !JSONUtil.isTypeJSON(response)) {
                log.info("代理：{}，响应异常: {}", this.markingModel.getIsvNo(), response);
                return Boolean.FALSE;
            }
            log.info("Marking Response: {}", response);

            JSONObject jsonObject = JSONUtil.parseObj(response);
            String code = jsonObject.get("code", String.class);
            String status = jsonObject.get("msg", String.class);

            return StrUtil.equals(code, "200") && StrUtil.equals(status, "ok");

        }

    }
}
