package com.kxs.lhb.basic.biz.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.yulichang.base.MPJBaseServiceImpl;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.core.exception.GlobalCustomerException;
import com.kxs.lhb.basic.api.dto.cusmoter.goods.NumbersDTO;
import com.kxs.lhb.basic.api.dto.tongyi.NumbersReq;
import com.kxs.lhb.basic.api.dto.tongyi.PackagesReq;
import com.kxs.lhb.basic.api.model.LhbGoods;
import com.kxs.lhb.basic.api.model.LhbGoodsActivities;
import com.kxs.lhb.basic.api.model.LhbGoodsSku;
import com.kxs.lhb.basic.api.vo.cusmoter.goods.GoodsInfoVO;
import com.kxs.lhb.basic.api.vo.cusmoter.goods.NumbersVO;
import com.kxs.lhb.basic.api.vo.tongyi.NumbersRes;
import com.kxs.lhb.basic.api.vo.tongyi.PackagesRes;
import com.kxs.lhb.basic.biz.channel.BasicService;
import com.kxs.lhb.basic.biz.channel.factory.ChannelFactory;
import com.kxs.lhb.basic.biz.mapper.LhbGoodsMapper;
import com.kxs.lhb.basic.biz.service.LhbGoodsActivitiesService;
import com.kxs.lhb.basic.biz.service.LhbGoodsService;
import com.kxs.lhb.basic.biz.service.LhbGoodsSkuService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;


/**
 * 产品表(LhbGoods)表服务实现类
 *
 * @author 系统
 * @since 2024-10-18 16:10:13
 */
@Service("lhbGoodsService")
@RequiredArgsConstructor
@Slf4j
public class LhbGoodsServiceImpl extends MPJBaseServiceImpl<LhbGoodsMapper, LhbGoods> implements LhbGoodsService {

    private final ChannelFactory channelFactory;

    private final LhbGoodsSkuService goodsSkuService;

    private final LhbGoodsActivitiesService goodsActivitiesService;


    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean addGoods(LhbGoods param) {

        boolean exists = exists(Wrappers.lambdaQuery(LhbGoods.class).eq(LhbGoods::getExternalId, param.getExternalId()));
        if (exists) {
            throw new GlobalCustomerException("三方产品ID已存在");
        }

        List<PackagesRes> packages = channelFactory.getChannel(param.getIfCode()).getPackages(PackagesReq.builder().build());

        Optional<PackagesRes> first = packages.stream().filter(item -> param.getExternalId().equals(item.getId())).findFirst();

        if (first.isEmpty()) {
            throw new GlobalCustomerException("未查询到第三方套餐ID");
        }
        first.ifPresent(item -> {

            save(param);
            refreshGoods(param, item);
        });

        return Boolean.TRUE;
    }

    @Override
    public Boolean updateGoods(LhbGoods param) {

        List<PackagesRes> packages = channelFactory.getChannel(param.getIfCode()).getPackages(PackagesReq.builder().build());

        Optional<PackagesRes> first = packages.stream().filter(item -> param.getExternalId().equals(item.getId())).findFirst();

        if (first.isEmpty()) {
            throw new GlobalCustomerException("未查询到第三方套餐ID");
        }

        first.ifPresent(item -> {

            updateById(param);
            refreshGoods(param, item);
        });

        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean removeByGoodsId(Integer id) {

        removeById(id);

        goodsSkuService.list(Wrappers.lambdaQuery(LhbGoodsSku.class).eq(LhbGoodsSku::getGoodsId, id)).forEach(goodsSku -> {
            goodsActivitiesService.remove(Wrappers.lambdaQuery(LhbGoodsActivities.class).eq(LhbGoodsActivities::getSkuId, goodsSku.getId()));
            goodsSkuService.removeById(goodsSku.getId());
        });

        return Boolean.TRUE;
    }

    @Override
    public List<NumbersVO> getNumbers(NumbersDTO param) {

        LhbGoods goods = getById(param.getGoodsId());

        NumbersRes numbersRes = channelFactory.getChannel(goods.getIfCode()).getNumbers(NumbersReq.builder().regionId(param.getAreaCode())
                .pageSize(30)
                .currentPage(1)
                .fuzzyTag(param.getFuzzyTag())
                .fuzzyKey(param.getFuzzyKey()).build());

        List<NumbersVO> list = new ArrayList<>();
        numbersRes.getNumList().forEach(item -> {
            NumbersVO numbersVO = new NumbersVO();
            numbersVO.setPhone(item.getAccessNum());
            numbersVO.setBeautifulTag(item.getBeautifulTag());
            numbersVO.setReserveFee(item.getReserveFee());
            list.add(numbersVO);
        });
        return list;
    }

    @Override
    public GoodsInfoVO detail(Integer id) {

        LhbGoods goods = getById(id);
        GoodsInfoVO goodsInfoVO = new GoodsInfoVO();
        BeanUtils.copyProperties(goods, goodsInfoVO);
        goodsInfoVO.setSkuList(new ArrayList<>());
        List<LhbGoodsSku> goodsSku = goodsSkuService.list(Wrappers.lambdaQuery(LhbGoodsSku.class).eq(LhbGoodsSku::getGoodsId, id));
        goodsSku.forEach(item -> {
            GoodsInfoVO.GoodsSkuVO goodsSkuVO = new GoodsInfoVO.GoodsSkuVO();
            BeanUtils.copyProperties(item, goodsSkuVO);
            List<LhbGoodsActivities> activities = goodsActivitiesService.list(Wrappers.lambdaQuery(LhbGoodsActivities.class).eq(LhbGoodsActivities::getSkuId, item.getId()));
            goodsSkuVO.setGoodsActivities(activities);
            goodsInfoVO.getSkuList().add(goodsSkuVO);
        });

        goods.setMakeCount(goods.getMakeCount() + 1);
        goods.updateById();

        return goodsInfoVO;
    }

    @Override
    @Async
    public void goodsInfoTask() {

        List<LhbGoods> list = list(Wrappers.lambdaQuery(LhbGoods.class).eq(LhbGoods::getStatus, CommonConstants.SUCCESS));

        list.forEach(goods -> {

            Boolean aBoolean = updateGoods(goods);

        });
    }

    @Override
    public List<PackagesRes> getOutGoods(String ifCode) {

        return channelFactory.getChannel(ifCode).getPackages(PackagesReq.builder().build());
    }


    private void refreshGoods(LhbGoods goods, PackagesRes packages) {

        List<PackagesRes.GoodsChild> goodsChildList = packages.getGoodsChildList();

        //删除不存在的sku
        goodsSkuService.remove(Wrappers.lambdaQuery(LhbGoodsSku.class)
                .eq(LhbGoodsSku::getGoodsId, goods.getId())
                .notIn(LhbGoodsSku::getExternalSkuId, goodsChildList.stream().map(PackagesRes.GoodsChild::getId).toList()));

        goodsChildList.forEach(goodsChild -> {
            LhbGoodsSku goodsSku = goodsSkuService.getOne(Wrappers.lambdaQuery(LhbGoodsSku.class).eq(LhbGoodsSku::getExternalSkuId, goodsChild.getId()));
            if (goodsSku == null) {
                goodsSku = new LhbGoodsSku();
            }
            goodsSku.setGoodsId(goods.getId());
            goodsSku.setExternalSkuId(goodsChild.getId());
            goodsSku.setDetails(goodsChild.getChildInfo());
            goodsSku.setPackageName(goodsChild.getChildName());
            goodsSku.setMonthFee(new BigDecimal(goodsChild.getChildFee()));
            goodsSku.setProductId(goodsChild.getProductId());
            goodsSkuService.saveOrUpdate(goodsSku);
            //活动信息
            List<PackagesRes.Activities> activities = goodsChild.getActivities();
            //删除不存在的活动
            goodsActivitiesService.remove(Wrappers.lambdaQuery(LhbGoodsActivities.class)
                    .eq(LhbGoodsActivities::getSkuId, goodsSku.getId())
                    .notIn(LhbGoodsActivities::getActivityCode, activities.stream().map(PackagesRes.Activities::getOfferCode).toList()));

            for (PackagesRes.Activities activitiesItem : activities) {

                LhbGoodsActivities goodsActivities = goodsActivitiesService.getOne(Wrappers.lambdaQuery(LhbGoodsActivities.class)
                        .eq(LhbGoodsActivities::getActivityCode, activitiesItem.getOfferCode()));
                if (goodsActivities == null) {
                    goodsActivities = new LhbGoodsActivities();
                }
                goodsActivities.setSkuId(goodsSku.getId());
                goodsActivities.setActivityCode(activitiesItem.getOfferCode());
                goodsActivities.setActivityName(activitiesItem.getOfferName());
                goodsActivities.setActivityDesc(activitiesItem.getOfferDesc());
                goodsActivities.setDiscount(StrUtil.isNotBlank(activitiesItem.getOfferDiscount()) ? Integer.valueOf(activitiesItem.getOfferDiscount()) : null);
                goodsActivities.setModels(Integer.valueOf(activitiesItem.getOfferModes()));
                goodsActivities.setDownAmt(StrUtil.isNotBlank(activitiesItem.getStraightDownAmount()) ? new BigDecimal(activitiesItem.getStraightDownAmount()) : null);
                goodsActivitiesService.saveOrUpdate(goodsActivities);
            }
        });
    }

}

