package com.kxs.lhb.basic.biz.service.impl;

import cn.hutool.core.util.ArrayUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yulichang.base.MPJBaseServiceImpl;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.mq.handlers.IMQSender;
import com.kxs.lhb.basic.api.amqp.RabbitLhbBindQueueMQ;
import com.kxs.lhb.basic.api.amqp.RabbitLhbOrderQueueMQ;
import com.kxs.lhb.basic.api.dto.admin.sysNotify.SysNotifyDTO;
import com.kxs.lhb.basic.api.dto.admin.sysNotify.SysNotifyPageDTO;
import com.kxs.lhb.basic.biz.mapper.LhbNotifyMapper;
import com.kxs.lhb.basic.biz.mq.RabbiLhbOrderQueueListener;
import com.kxs.lhb.basic.biz.mq.model.params.BindNotify;
import com.kxs.lhb.basic.biz.mq.model.params.OrderNotify;
import com.kxs.lhb.basic.biz.service.LhbNotifyService;
import org.springframework.stereotype.Service;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import com.kxs.lhb.basic.api.model.LhbNotify;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;


/**
 * 通知记录表(LhbNotify)表服务实现类
 *
 * @author 系统
 * @since 2024-10-18 16:10:12
 */
@Service("lhbNotifyService")
@RequiredArgsConstructor
@Slf4j
public class LhbNotifyServiceImpl extends MPJBaseServiceImpl<LhbNotifyMapper, LhbNotify> implements LhbNotifyService {

    private final IMQSender mqSender;

    @Override
    public LhbNotify getByNoteId(String notifyId) {

        return this.getOne(Wrappers.<LhbNotify>lambdaQuery().eq(LhbNotify::getNotifyId, notifyId));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void bindPush(BindNotify bindNotify, String isvNo) {

        //保存推送消息次数
        LhbNotify notify = new LhbNotify();
        notify.setIsvNo(isvNo);
        notify.setNotifyId(IdUtil.simpleUUID());
        notify.setParams(JSON.toJSONString(bindNotify));
        notify.setClassName(CommonConstants.BIND_PUSH_NAME);
        save(notify);
        //推送绑定数据
        RabbitLhbBindQueueMQ.MsgEntity msgEntity = new RabbitLhbBindQueueMQ.MsgEntity();
        msgEntity.setNotifyId(notify.getNotifyId());
        mqSender.send(RabbitLhbBindQueueMQ.build(msgEntity), 5);
        log.info("手机号码:{},推送预约数据成功:{}", bindNotify.getMobile(), JSON.toJSONString(bindNotify));
    }

    @Override
    public void orderPush(OrderNotify orderNotify, String isvNo) {

        //保存推送消息次数
        LhbNotify notify = new LhbNotify();
        notify.setIsvNo(isvNo);
        notify.setNotifyId(IdUtil.simpleUUID());
        notify.setParams(JSON.toJSONString(orderNotify));
        notify.setClassName(CommonConstants.ORDER_PUSH_NAME);
        save(notify);

        //推送交易数据
        RabbitLhbOrderQueueMQ.MsgEntity msgEntity = new RabbitLhbOrderQueueMQ.MsgEntity();
        msgEntity.setNotifyId(notify.getNotifyId());
        mqSender.send(RabbitLhbOrderQueueMQ.build(msgEntity), 5);
        log.info("订单:{},推送订单激活数据成功:{}", orderNotify.getMobile(), JSON.toJSONString(orderNotify));
    }

    @Override
    public Page<LhbNotify> notifyPage(Page<LhbNotify> page, SysNotifyPageDTO param) {
        QueryWrapper<LhbNotify> wrapper = Wrappers.query();
        if (StrUtil.isNotBlank(param.getIsvNo())) {
            wrapper.eq("isv_no", param.getIsvNo());
        }
        if (StrUtil.isNotBlank(param.getClassName())) {
            wrapper.eq("class_name", param.getClassName());
        }
        if (StrUtil.isNotBlank(param.getNotifyId())) {
            wrapper.eq("notify_id", param.getNotifyId());
        }
        if (StrUtil.isNotBlank(param.getMobile())) {
            wrapper.eq("JSON_EXTRACT(params, '$.mobile')", param.getMobile());
        }
        if (StrUtil.isNotBlank(param.getOrderNo())) {
            wrapper.eq("JSON_EXTRACT(params, '$.orderNo')", param.getOrderNo());
        }
        if (param.getStatus() != null) {
            wrapper.eq("status", param.getStatus());
        }

        if (ArrayUtil.isNotEmpty(param.getNotifyTime())) {
            wrapper.ge("notify_time", param.getNotifyTime()[0])
                    .le("notify_time", param.getNotifyTime()[1]);
        }
        wrapper.orderByDesc("create_time");

        return baseMapper.selectPage(page, wrapper);
    }

    @Override
    public Boolean notifyBatchData(SysNotifyDTO param) {

        List<LhbNotify> llbNotifies = baseMapper.selectList(Wrappers.lambdaQuery(LhbNotify.class).in(LhbNotify::getId, param.getIds()));
        for (LhbNotify notify : llbNotifies) {
            notify.setNotifyCount(1);
            notify.setStatus(0);
            updateById(notify);

            if(CommonConstants.ORDER_PUSH_NAME.equals(notify.getClassName())){
                //推送交易数据
                RabbitLhbOrderQueueMQ.MsgEntity msgEntity = new RabbitLhbOrderQueueMQ.MsgEntity();
                msgEntity.setNotifyId(notify.getNotifyId());
                mqSender.send(RabbitLhbOrderQueueMQ.build(msgEntity), 5);
                log.info("补推订单数据成功:{}", JSON.toJSONString(notify.getParams()));
            }
            if(CommonConstants.BIND_PUSH_NAME.equals(notify.getClassName())){
                //推送绑定数据
                RabbitLhbBindQueueMQ.MsgEntity msgEntity = new RabbitLhbBindQueueMQ.MsgEntity();
                msgEntity.setNotifyId(notify.getNotifyId());
                mqSender.send(RabbitLhbBindQueueMQ.build(msgEntity), 5);
                log.info("补推绑定数据成功:{}", JSON.toJSONString(notify.getParams()));
            }
        }

        return Boolean.TRUE;
    }
}

