package com.kxs.lhb.basic.biz.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.ReUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.yulichang.base.MPJBaseServiceImpl;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.excel.converters.ImportAsyncInfo;
import com.kxs.common.excel.vo.ErrorMessage;
import com.kxs.lhb.basic.api.constant.enums.OrderStatusEnum;
import com.kxs.lhb.basic.api.model.LhbArea;
import com.kxs.lhb.basic.api.model.LhbOrder;
import com.kxs.lhb.basic.api.model.LhbOrderRecharge;
import com.kxs.lhb.basic.api.util.TotalDateUtil;
import com.kxs.lhb.basic.api.vo.admin.bill.BillExcelVO;
import com.kxs.lhb.basic.biz.mapper.LhbOrderRechargeMapper;
import com.kxs.lhb.basic.biz.mq.model.params.BindNotify;
import com.kxs.lhb.basic.biz.mq.model.params.OrderNotify;
import com.kxs.lhb.basic.biz.service.LhbNotifyService;
import com.kxs.lhb.basic.biz.service.LhbOrderRechargeService;
import com.kxs.lhb.basic.biz.service.LhbOrderService;
import org.springframework.beans.BeanUtils;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.BindingResult;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.HashSet;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.concurrent.TimeUnit;


/**
 * 订单号码充值记录(LhbOrderRecharge)表服务实现类
 *
 * @author 系统
 * @since 2024-10-18 16:10:14
 */
@Service("lhbOrderRechargeService")
@RequiredArgsConstructor
@Slf4j
public class LhbOrderRechargeServiceImpl extends MPJBaseServiceImpl<LhbOrderRechargeMapper, LhbOrderRecharge> implements LhbOrderRechargeService {

    private final RedisTemplate<String, Object> redisTemplate;

    private final LhbOrderService orderService;

    private final LhbNotifyService notifyService;

    private final static String REGEX = "\\d+\\.\\d+";

    @Override
    public void importBill(List<BillExcelVO> billExcelList, String uuid, BindingResult bindingResult) {
        //上传内容信息
        ImportAsyncInfo importAsyncInfo = new ImportAsyncInfo();
        importAsyncInfo.setTotality(billExcelList.size());

        for (BillExcelVO billExcelVO : billExcelList) {
            Set<String> errorMsg = new HashSet<>();
            LhbOrderRecharge recharge = getOne(Wrappers.lambdaQuery(LhbOrderRecharge.class).eq(LhbOrderRecharge::getOrderSn, billExcelVO.getOrderSn()));
            if (recharge != null) {
                errorMsg.add(billExcelVO.getOrderSn() + "账单已导入！");
            }
            LhbOrder order = orderService.getOne(Wrappers.lambdaQuery(LhbOrder.class)
                    .eq(LhbOrder::getStatus, OrderStatusEnum.PAY.getCode())
                    .eq(LhbOrder::getIsAct, CommonConstants.SUCCESS)
                    .eq(LhbOrder::getMakeMobile, billExcelVO.getPhone()).last("limit 1"));
            if (order == null) {
                errorMsg.add(billExcelVO.getPhone() + "号码不存在！");
            }
            if (CollUtil.isNotEmpty(errorMsg)) {
                ErrorMessage errorMessage = new ErrorMessage(billExcelVO.getLineNum(), errorMsg);
                importAsyncInfo.errAdd(1);
                importAsyncInfo.errListAdd(errorMessage);
                importAsyncInfo.doneAdd(1);
            } else {
                LhbOrderRecharge orderRecharge = new LhbOrderRecharge();
                BeanUtils.copyProperties(billExcelVO, orderRecharge);
                Optional<String> first = ReUtil.findAll(REGEX, billExcelVO.getBillFee(), 0).stream().findFirst();
                first.ifPresent(s -> orderRecharge.setBillFee(NumberUtil.mul(new BigDecimal(s), 100)));
                orderRecharge.setIfCode(order.getIfCode());
                orderRecharge.setIsvNo(order.getIsvNo());
                orderRecharge.setBillMonth(TotalDateUtil.getMonthNumber(billExcelVO.getBillMonth().toLocalDate()));
                save(orderRecharge);

                OrderNotify orderNotify = OrderNotify.builder()
                        .mobile(order.getMakeMobile())
                        .isvNo(order.getIsvNo())
                        .amount(orderRecharge.getBillFee())
                        .month(orderRecharge.getBillMonth())
                        .build();
                notifyService.orderPush(orderNotify, order.getIsvNo());

                importAsyncInfo.sucAdd(1);
                importAsyncInfo.doneAdd(1);
            }

            redisTemplate.opsForValue().set(uuid, JSON.toJSONString(importAsyncInfo), 15, TimeUnit.MINUTES);
        }
    }
}