package com.kxs.lhb.basic.biz.service.impl;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.IdcardUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.Header;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.yulichang.base.MPJBaseServiceImpl;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.core.exception.GlobalCustomerException;
import com.kxs.common.core.util.AssertUtil;
import com.kxs.common.mq.handlers.IMQSender;
import com.kxs.common.pay.enums.PayPlatformEnum;
import com.kxs.common.pay.enums.PayStatusCommEnum;
import com.kxs.common.pay.factory.PaymentFactory;
import com.kxs.common.pay.model.*;
import com.kxs.common.security.util.SecurityUtils;
import com.kxs.lhb.basic.api.amqp.RabbitOrderTimeoutQueueMQ;
import com.kxs.lhb.basic.api.constant.enums.NotifyStatusEnum;
import com.kxs.lhb.basic.api.constant.enums.OrderStatusEnum;
import com.kxs.lhb.basic.api.dto.tongyi.OrderCancelReq;
import com.kxs.lhb.basic.api.dto.tongyi.OrderSubmitReq;
import com.kxs.lhb.basic.api.dto.tongyi.PreNumbersReq;
import com.kxs.lhb.basic.api.dto.tongyi.QueryOrderReq;
import com.kxs.lhb.basic.api.model.*;
import com.kxs.lhb.basic.api.vo.admin.sysOrder.QueryLogisticsVO;
import com.kxs.lhb.basic.api.vo.tongyi.QueryLogisticsRes;
import com.kxs.lhb.basic.biz.channel.factory.ChannelFactory;
import com.kxs.lhb.basic.biz.mapper.LhbOrderMapper;
import com.kxs.lhb.basic.biz.mq.model.params.BindNotify;
import com.kxs.lhb.basic.biz.mq.model.params.OrderNotify;
import com.kxs.lhb.basic.biz.service.*;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * 订单表(LhbOrder)表服务实现类
 *
 * @author 系统
 * @since 2024-10-18 16:10:13
 */
@Service("lhbOrderService")
@RequiredArgsConstructor
@Slf4j
public class LhbOrderServiceImpl extends MPJBaseServiceImpl<LhbOrderMapper, LhbOrder> implements LhbOrderService {

    private final ChannelFactory channelFactory;

    private final LhbUserService userService;

    private final LhbGoodsService goodsService;

    private final LhbGoodsSkuService goodsSkuService;

    private final LhbGoodsActivitiesService goodsActivitiesService;

    private final PaymentFactory paymentFactory;

    private final IMQSender mqSender;

    private final LhbNotifyService notifyService;

    private final LhbIsvInfoService isvInfoService;

    private final LhbAreaService areaService;

    @Override
    public List<QueryLogisticsVO> queryLogistics(Integer id) {

        LhbOrder order = getById(id);

        if(StrUtil.isBlank(order.getOutOrderSn())){
            throw new GlobalCustomerException("订单未下单");
        }
        QueryOrderReq req = QueryOrderReq.builder().orderId(order.getOutOrderSn()).build();
        QueryLogisticsRes queryLogisticsRes = channelFactory.getChannel(order.getIfCode()).queryLogistics(req);
        order.setExpressNo(queryLogisticsRes.getExpressNo());
        order.updateById();

        List<QueryLogisticsVO> list = new ArrayList<>();
        queryLogisticsRes.getInfoList().forEach(item -> {
            QueryLogisticsVO logisticsVO = new QueryLogisticsVO();
            logisticsVO.setExpressNo(queryLogisticsRes.getExpressNo());
            logisticsVO.setContent(item.getContent());
            logisticsVO.setOperationTime(item.getOperationTime());
            list.add(logisticsVO);
        });
        return list;
    }


    @Override
    public Integer prePhone(LhbOrder order) {

        LhbUser user = userService.getById(SecurityUtils.getUser().getId());

        LhbGoods goods = goodsService.getById(order.getGoodsId());

        String ageSection = goods.getAgeSection();
        String[] split = ageSection.split(StrUtil.DASHED);
        int age = IdcardUtil.getAgeByIdCard(order.getIdCard());
        if(age < Integer.parseInt(split[0]) || age > Integer.parseInt(split[1])){
            throw new GlobalCustomerException("办理年龄段在" + ageSection + "岁之间");
        }
        LhbIsvInfo isvInfo = isvInfoService.getByIsvNo(order.getIsvNo());
        if(isvInfo == null){
            throw new GlobalCustomerException("服务商不存在");
        }
        if(!verifyIdName(order.getIdCard(), order.getCustName())){
            throw new GlobalCustomerException("身份证和姓名不一致");
        }
        //订单号
        String orderSn = CommonConstants.ORDER_SN_PREFIX + IdUtil.getSnowflakeNextIdStr();
        order.setOrderSn(orderSn);
        order.setUserId(user.getId());

        //预占号码
        PreNumbersReq req = PreNumbersReq.builder()
                .regionId(order.getRegionId())
                .idenNr(order.getIdCard())
                .number(order.getMakeMobile()).build();
        channelFactory.getChannel(goods.getIfCode()).preNumber(req);

        order.insert();

        //发送订单延时取消消息
        RabbitOrderTimeoutQueueMQ.MsgEntity msgEntity = new RabbitOrderTimeoutQueueMQ.MsgEntity();
        msgEntity.setOrderId(order.getId());
        mqSender.send(RabbitOrderTimeoutQueueMQ.build(msgEntity), 60 * 20);

        return order.getId();
    }
    private Boolean verifyIdName(String idCard, String name) {
        String url = "https://dfidveri.market.alicloudapi.com/verify_id_name";
        //调用二要素认证
        Map<String, Object> param = new HashMap<>();
        param.put("id_number", idCard);
        param.put("name", name);
        String result = HttpRequest.post(url)
                .header(Header.AUTHORIZATION, "APPCODE " + "8e5704921ca3422f80f0deb935a7ddc6")
                .header(Header.CONTENT_TYPE, "application/x-www-form-urlencoded; charset=UTF-8")
                .timeout(20000)
                .form(param)
                .execute().body();
        if (StrUtil.isEmpty(result) || !JSONUtil.isTypeJSON(result)) {
            log.error("实名认证：{}，响应异常: {}", name, result);
            return Boolean.FALSE;
        }
        JSONObject jsonObject = JSONUtil.parseObj(result);
        if (!"OK".equals(jsonObject.getStr("status"))) {
            throw  new GlobalCustomerException(jsonObject.getStr("reason"));
        }
        int state = jsonObject.getInt("state");
        if(state != 1){
            return Boolean.FALSE;
        }
        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Integer submit(LhbOrder param) {

        LhbOrder order = getById(param.getId());
        AssertUtil.isTrue(order.getStatus().equals(OrderStatusEnum.NO_PAY.getCode()), "订单状态异常");

        LhbGoods goods = goodsService.getById(param.getGoodsId());
        order.setIfCode(goods.getIfCode());
        order.setOperators(goods.getOperators());
        order.setAddress(param.getAddress());
        order.setArea(param.getArea());
        order.setContMobile(param.getContMobile());
        order.setCustName(param.getCustName());
        order.setPackageName(param.getPackageName());
        order.setGoodsId(param.getGoodsId());
        order.setSkuId(param.getSkuId());
        order.setServerFee(goods.getServerFee());

        List<LhbArea> areas = areaService.getListAreas(List.of(param.getArea().split(StrUtil.COMMA)));
        if(areas.size() != 3){
            throw new GlobalCustomerException("地区传入错误");
        }
        LhbGoodsSku goodsSku = goodsSkuService.getById(param.getSkuId());
        order.setPackageName(goodsSku.getPackageName());

        List<LhbGoodsActivities> activities = goodsActivitiesService.list(Wrappers.lambdaQuery(LhbGoodsActivities.class).eq(LhbGoodsActivities::getSkuId, goodsSku.getId()));

        //如果有服务费 需要先支付 回调再下单
        if(order.getServerFee().compareTo(BigDecimal.ZERO) == 0){

            order.setStatus(OrderStatusEnum.PAY.getCode());
            order.setPayTime(LocalDateTime.now());
            //三方下单
            OrderSubmitReq req = OrderSubmitReq.builder()
                    .goodsId(goods.getExternalId())
                    .goodsSkuId(goodsSku.getExternalSkuId())
                    .offerCodes(!activities.isEmpty() ? activities.stream().map(LhbGoodsActivities::getActivityCode).collect(Collectors.joining(",")) : "")
                    .payMoney("0")
                    .number(order.getMakeMobile())
                    .custName(order.getCustName())
                    .contNumber(order.getContMobile())
                    .idenNr(order.getIdCard())
                    .receiveName(order.getCustName())
                    .receiveMobile(order.getContMobile())
                    .receiveAddress(order.getAddress())
                    .area(order.getArea())
                    .preNumber(Boolean.FALSE)
                    .regionId(order.getRegionId()).build();
            String orderId = channelFactory.getChannel(order.getIfCode()).orderSubmit(req);
            order.setOutOrderSn(orderId);
            //下单成功推送预约信息到下游
            sendToOrder(order, NotifyStatusEnum.NORMAL);
        }
        order.updateById();

        return order.getId();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void payBack(String outTradeNo, String transactionId) {
        LhbOrder order = getOne(Wrappers.lambdaQuery(LhbOrder.class).eq(LhbOrder::getOrderSn, outTradeNo));
        if(order.getStatus() != OrderStatusEnum.NO_PAY.getCode()){
            throw new GlobalCustomerException("订单状态错误");
        }
        LhbGoods goods = goodsService.getById(order.getGoodsId());
        LhbGoodsSku goodsSku = goodsSkuService.getById(order.getSkuId());

        order.setPayTradeNo(transactionId);
        order.setStatus(OrderStatusEnum.PAY.getCode());
        order.setPayTime(LocalDateTime.now());

        List<LhbGoodsActivities> activities = goodsActivitiesService.list(Wrappers.lambdaQuery(LhbGoodsActivities.class).eq(LhbGoodsActivities::getSkuId, goodsSku.getId()));
        //三方下单
        OrderSubmitReq req = OrderSubmitReq.builder()
                .goodsId(goods.getExternalId())
                .goodsSkuId(goodsSku.getExternalSkuId())
                .offerCodes(!activities.isEmpty() ? activities.stream().map(LhbGoodsActivities::getActivityCode).collect(Collectors.joining(",")) : "")
                .payMoney("0")
                .number(order.getMakeMobile())
                .custName(order.getCustName())
                .contNumber(order.getContMobile())
                .idenNr(order.getIdCard())
                .receiveName(order.getCustName())
                .receiveMobile(order.getContMobile())
                .receiveAddress(order.getAddress())
                .area(order.getArea())
                .preNumber(Boolean.FALSE)
                .regionId(order.getRegionId()).build();
        String orderId = channelFactory.getChannel(order.getIfCode()).orderSubmit(req);
        order.setOutOrderSn(orderId);
        order.updateById();

        //下单成功推送预约信息到下游
        sendToOrder(order, NotifyStatusEnum.NORMAL);
    }


    @Override
    public Object payOrder(LhbOrder param) {

        LhbUser user = userService.getById(SecurityUtils.getUser().getId());

        LhbOrder order = getById(param.getId());

        PayRequest payReq = new PayRequest();
        payReq.setPayTypeEnum(PayPlatformEnum.WX);
        payReq.setOutTradeNo(order.getOrderSn());
        payReq.setSubject(order.getPackageName());
        payReq.setTotalAmount(NumberUtil.div(order.getServerFee().doubleValue(), 100));
        //扩展参数
        payReq.setPassbackParams(CommonConstants.PRODUCT_FLAG);
        payReq.setOpenid(user.getWxOpenid());

        return paymentFactory.getPayService(PayPlatformEnum.WX.getType()).jsPay(payReq);
    }

    @Override
    public void changeTimeoutOrder(LhbOrder order) {

        order.setStatus(OrderStatusEnum.CANCEL.getCode());

        //有押金才查询是否支付
        if(order.getServerFee().compareTo(BigDecimal.ZERO) > 0){
            QueryRequest queryReq = QueryRequest.builder()
                    .outTradeNo(order.getOrderSn())
                    .build();

            try{
                QueryResponse query = paymentFactory.getPayService(PayPlatformEnum.WX.getType()).query(queryReq);
                if (query != null && PayStatusCommEnum.TRADE_SUCCESS == query.getTradeStatus() ) {
                    order.setStatus( OrderStatusEnum.PAY.getCode());
                    order.setPayTime(LocalDateTime.now());
                    order.setPayTradeNo(query.getTradeNo());

                    LhbGoods goods = goodsService.getById(order.getGoodsId());
                    LhbGoodsSku goodsSku = goodsSkuService.getById(order.getSkuId());
                    List<LhbGoodsActivities> activities = goodsActivitiesService.list(Wrappers.lambdaQuery(LhbGoodsActivities.class).eq(LhbGoodsActivities::getSkuId, goodsSku.getId()));
                    //三方下单
                    OrderSubmitReq req = OrderSubmitReq.builder()
                            .goodsId(goods.getExternalId())
                            .goodsSkuId(goodsSku.getExternalSkuId())
                            .offerCodes(!activities.isEmpty() ? activities.stream().map(LhbGoodsActivities::getActivityCode).collect(Collectors.joining(",")) : "")
                            .payMoney("0")
                            .number(order.getMakeMobile())
                            .custName(order.getCustName())
                            .contNumber(order.getContMobile())
                            .idenNr(order.getIdCard())
                            .receiveName(order.getCustName())
                            .receiveMobile(order.getContMobile())
                            .receiveAddress(order.getAddress())
                            .area(order.getArea())
                            .preNumber(Boolean.FALSE)
                            .regionId(order.getRegionId()).build();
                    String orderId = channelFactory.getChannel(order.getIfCode()).orderSubmit(req);
                    order.setOutOrderSn(orderId);
                }
            }catch (Exception e){
                log.error("查询微信订单失败", e);
            }
        }
        updateById(order);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean cancelOrder(LhbOrder param) {

        LhbOrder order = getById(param.getId());
        if(order.getIsAct() == 1){
            throw new GlobalCustomerException("订单已激活，无法取消");
        }
        if(order.getOutStatus() == 41){
            throw new GlobalCustomerException("配送中，不可取消订单");
        }
        if(order.getOutStatus() == 6){
            throw new GlobalCustomerException("订单正在取消中");
        }

        if(order.getServerFee().compareTo(BigDecimal.ZERO) == 0){
            order.setStatus(OrderStatusEnum.CANCEL.getCode());
        }
        order.setRemark(param.getRemark());
        order.setOutStatus(3);
        order.updateById();

        OrderCancelReq req = OrderCancelReq.builder()
                .orderId(order.getOutOrderSn())
                .returnCause(param.getRemark())
                .applyPerson(SecurityUtils.getUser().getName()).build();
        channelFactory.getChannel(order.getIfCode()).orderCancel(req);



        sendToOrder(order, NotifyStatusEnum.CANCEL);
        return Boolean.TRUE;
    }

    @Override
    public Boolean refundFee(LhbOrder param) {

        LhbOrder order = getById(param.getId());
        if(order == null){
            throw new GlobalCustomerException("订单不存在");
        }
        if(param.getRefundPrice() == null){
            throw new GlobalCustomerException("退款金额不能为空");
        }
        RefundRequest req = RefundRequest.builder().refundReason(param.getRemark())
                .outTradeNo(order.getOrderSn())
                .refundFee(NumberUtil.div(param.getRefundPrice().doubleValue(), 100))
                .totalFee(NumberUtil.div(order.getServerFee().doubleValue(), 100))
                .outRefundNo(CommonConstants.REFUND_ORDER_PREFIX + IdUtil.getSnowflakeNextIdStr())
                .payTypeEnum(PayPlatformEnum.WX).build();
        RefundResponse refund = paymentFactory.getPayService(PayPlatformEnum.WX.getType()).refund(req);
        order.setRefundTradeNo(refund.getTradeNo());
        order.setRefundPrice(param.getRefundPrice());
        order.setStatus(OrderStatusEnum.REFUND.getCode());
        log.info("订单{}退款成功", order.getOrderSn());
        return order.updateById();
    }

    @Override
    @Async
    public void orderStatusTask() {
        List<LhbOrder> orders = list(Wrappers.lambdaQuery(LhbOrder.class)
                .eq(LhbOrder::getIsAct, CommonConstants.FAIL)
                .eq(LhbOrder::getStatus, OrderStatusEnum.PAY.getCode()));

        orders.forEach(order -> {
            QueryOrderReq req = QueryOrderReq.builder().orderId(order.getOutOrderSn()).build();
            String outStatus = channelFactory.getChannel(order.getIfCode()).queryStatus(req);

            LambdaUpdateWrapper<LhbOrder> updateWrapper = Wrappers.lambdaUpdate(LhbOrder.class).eq(LhbOrder::getId, order.getId()).set(LhbOrder::getOutStatus, outStatus);
            //更新状态
            if("41".equals(outStatus) || "2".equals(outStatus)){
                //41-配送中，不可取消订单 2-订单成功结束
                sendToOrder(order, "41".equals(outStatus) ? NotifyStatusEnum.DISTRIBUTION : NotifyStatusEnum.FINISH);
            }
            if("3".equals(outStatus)){
                //3-订单异常取消
                sendToOrder(order, NotifyStatusEnum.CANCEL);
                //如果是0服务费直接订单也变成已取消
                if(order.getServerFee().compareTo(BigDecimal.ZERO) == 0){
                    updateWrapper.set(LhbOrder::getStatus, OrderStatusEnum.CANCEL.getCode());
                }
            }

            update(updateWrapper);
        });
    }

    @Override
    @Async
    public void orderFirstCharge() {
        List<LhbOrder> orders = list(Wrappers.lambdaQuery(LhbOrder.class)
                .eq(LhbOrder::getIsAct, CommonConstants.FAIL)
                .eq(LhbOrder::getStatus, OrderStatusEnum.PAY.getCode()));

        orders.forEach(order -> {
            QueryOrderReq req = QueryOrderReq.builder().orderId(order.getOutOrderSn()).build();
            String firstCharge = channelFactory.getChannel(order.getIfCode()).queryFirstCharge(req);
            if(firstCharge.contains("50") || firstCharge.contains("100")){

                BigDecimal firstChargeAmt = firstCharge.contains("50") ? new BigDecimal("5000") : new BigDecimal("10000");

                //更新状态
                update(Wrappers.lambdaUpdate(LhbOrder.class).eq(LhbOrder::getId, order.getId())
                        .set(LhbOrder::getIsAct, CommonConstants.SUCCESS)
                        .set(LhbOrder::getFirstCharge, firstChargeAmt)
                        .set(LhbOrder::getIsFirstRecharge, CommonConstants.SUCCESS));

                order.setIsFirstRecharge(CommonConstants.SUCCESS);
                order.setFirstCharge(firstChargeAmt);
                order.setIsAct(CommonConstants.SUCCESS);
                sendToOrder(order, NotifyStatusEnum.ACT);
            }

        });
    }


    /**
     * 构建推送消息
     *
     * @param order            次序
     * @param notifyStatusEnum notify status 枚举
     */
    private void sendToOrder(LhbOrder order, NotifyStatusEnum notifyStatusEnum) {

        List<LhbArea> areas = areaService.getListAreas(List.of(order.getArea().split(StrUtil.COMMA)));
        BindNotify bindNotify = BindNotify.builder().mobile(order.getMakeMobile())
                .isvNo(order.getIsvNo())
                .employNum(order.getEmployNum())
                .productName(order.getPackageName())
                .firstRechargeAmount(order.getFirstCharge())
                .orderNo(order.getOrderSn())
                .receiveName(order.getCustName())
                .receiveMobile(order.getContMobile())
                .receiveAddress(order.getAddress())
                .status(notifyStatusEnum.getCode())
                .province(areas.get(0).getAreaName())
                .city(areas.get(1).getAreaName())
                .remark(order.getRemark())
                .createTime(LocalDateTimeUtil.format(LocalDateTime.now(), DatePattern.NORM_DATETIME_PATTERN))
                .build();
        notifyService.bindPush(bindNotify, order.getIsvNo());
    }


}

