package com.kxs.lhb.basic.biz.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.yulichang.base.MPJBaseServiceImpl;
import com.kxs.common.core.constant.CommonConstants;
import com.kxs.common.core.exception.GlobalCustomerException;
import com.kxs.lhb.basic.api.model.LhbUser;
import com.kxs.lhb.basic.biz.mapper.LhbUserMapper;
import com.kxs.lhb.basic.biz.service.LhbUserService;
import lombok.RequiredArgsConstructor;
import me.chanjar.weixin.common.bean.WxJsapiSignature;
import me.chanjar.weixin.common.bean.oauth2.WxOAuth2AccessToken;
import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.UUID;


/**
 * 用户表(LlbUser)表服务实现类
 *
 * @author 系统
 * @since 2024-09-02 18:02:35
 */
@Service("llbUserService")
@RequiredArgsConstructor
public class LlbUserServiceImpl extends MPJBaseServiceImpl<LhbUserMapper, LhbUser> implements LhbUserService {

    private final WxMpService wxMpService;
    private static final PasswordEncoder ENCODER = new BCryptPasswordEncoder();



    @Override
    public LhbUser wechat(String code) {

        try {

            WxOAuth2AccessToken accessToken = wxMpService.getOAuth2Service().getAccessToken(code);

//            WxOAuth2AccessToken accessToken = new WxOAuth2AccessToken();
//            accessToken.setOpenId(code);

            LhbUser user = getOne(Wrappers.lambdaQuery(LhbUser.class).eq(LhbUser::getWxOpenid, accessToken.getOpenId()));
            if (user == null) {
                user = new LhbUser();

                //加盐
                String salt = UUID.randomUUID().toString();
                user.setSalt(salt);

                user.setWxOpenid(accessToken.getOpenId());

                //登陆密码
                user.setPassword(ENCODER.encode(accessToken.getOpenId() + user.getSalt()));
                //保存用户注册信息
                baseMapper.insert(user);
                String number = String.format("%08d", user.getId());

                user.setNickname(CommonConstants.ORDER_SN_PREFIX + StrUtil.UNDERLINE + number);
                baseMapper.updateById(user);
            }

            return user;
        } catch (Exception e) {
            throw new GlobalCustomerException(e.getMessage());
        }
    }



    @Override
    public WxJsapiSignature getJsapiTicket(String url) {

        try {

            return  wxMpService.createJsapiSignature(url);
        } catch (WxErrorException e) {
            log.error("获取ticket失败，请重新登陆", e);
            throw new GlobalCustomerException("获取ticket失败，请重新登陆");
        }
    }

}

