/*
 *    Copyright (c) 2021-2025, LXQ All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: LXQ (609827073@qq.com)
 */

package com.kxs.daemon.quartz.util;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import com.kxs.daemon.quartz.exception.TaskException;
import com.kxs.daemon.quartz.entity.SysJob;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * 定时任务rest反射实现
 *
 * @author LXQ
 */
@Slf4j
@AllArgsConstructor
@Component("restTaskInvoke")
public class RestTaskInvoke implements ITaskInvoke {

	@Override
	public void invokeMethod(SysJob sysJob) throws TaskException {
		try {
			HttpRequest request = HttpUtil.createGet(sysJob.getExecutePath());
			request.execute();
		}
		catch (Exception e) {
			log.error("定时任务restTaskInvoke异常,执行任务：{}", sysJob.getExecutePath());
			throw new TaskException("定时任务restTaskInvoke业务执行失败,任务：" + sysJob.getExecutePath());
		}
	}

}
