
package com.kxs.lhb.system.biz.controller.admin;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.kxs.common.core.util.R;
import com.kxs.common.log.annotation.SysLog;
import com.kxs.common.security.annotation.Inner;
import com.kxs.lhb.system.biz.service.SysFileService;
import com.kxs.lhb.system.api.model.SysFile;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 文件管理
 *
 * @author 没秃顶的码农
 * @date 2019-06-18 17:18:42
 */
@RestController
@AllArgsConstructor
@RequestMapping("/sysFile")
@Tag(description = "sysFile", name = "文件管理")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class SysFileController {

    private final SysFileService sysFileService;

    /**
     * 分页查询
     *
     * @param page    分页对象
     * @param sysFile 文件管理
     * @return 分页
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page")
    public R getSysFilePage(@ParameterObject Page page, @ParameterObject SysFile sysFile) {
        LambdaQueryWrapper<SysFile> wrapper = Wrappers.<SysFile>lambdaQuery()
				.eq(sysFile.getType() != null, SysFile::getType, sysFile.getType())
                .like(StrUtil.isNotBlank(sysFile.getFileName()), SysFile::getFileName, sysFile.getFileName())
                .orderByDesc(SysFile::getId);
        return R.ok(sysFileService.page(page, wrapper));
    }

    /**
     * 通过id删除文件管理
     *
     * @param ids id 列表
     * @return R
     */
    @Operation(summary = "通过id删除文件管理", description = "通过id删除文件管理")
    @SysLog("删除文件管理")
    @PostMapping("/removeByIds")
    @PreAuthorize("@pms.hasPermission('sys_file_del')")
    public R removeById(@RequestBody List<Long> ids) {

        return R.ok(sysFileService.deleteFile(ids));
    }

    /**
     * 保存文件
     *
     * @param file 资源
     * @return R
     */
    @Inner
    @PostMapping(value = "/save")
    public R save(@Valid @RequestBody SysFile file) {

        return R.ok(sysFileService.save(file));
    }

    /**
     * 获取文件
     *
     * @param bucket   桶名称
     * @param fileName 文件空间/名称
     */
    @Inner(false)
    @GetMapping("/file")
    public R file(@RequestParam("bucketName") String bucket, @RequestParam("fileName") String fileName, HttpServletResponse response) {

        return R.ok(sysFileService.getFile(bucket, fileName, response));
    }


}
