package com.kxs.lhb.system.biz.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yulichang.base.MPJBaseService;
import com.kxs.lhb.system.api.dto.admin.UserDTO;
import com.kxs.lhb.system.api.dto.admin.UserInfo;
import com.kxs.lhb.system.api.vo.admin.UserVO;
import com.kxs.common.core.util.R;
import com.kxs.lhb.system.api.model.SysUser;


/**
 * @author 秃顶的码农
 * @date 2023/10/31
 */
public interface SysUserService extends MPJBaseService<SysUser> {

	/**
	 * 用户名密码登录
	 * @param username 用户名
	 * @return userInfo
	 */
	UserInfo loadUserByUsername(String username);

	/**
	 * 查询用户信息
	 * @param sysUser 用户
	 * @return userInfo
	 */
	UserInfo findUserInfo(SysUser sysUser);

	/**
	 * 分页查询用户信息（含有角色信息）
	 * @param page 分页对象
	 * @param userDTO 参数列表
	 * @return
	 */
	IPage getUsersWithRolePage(Page page, UserDTO userDTO);

	/**
	 * 删除用户
	 * @param ids 用户
	 * @return boolean
	 */
	Boolean deleteUserByIds(Long[] ids);

	/**
	 * 更新当前用户基本信息
	 * @param userDto 用户信息
	 * @return Boolean
	 */
	R<Boolean> updateUserInfo(UserDTO userDto);

	/**
	 * 更新指定用户信息
	 * @param userDto 用户信息
	 * @return
	 */
	Boolean updateUser(UserDTO userDto);

	/**
	 * 通过ID查询用户信息
	 * @param id 用户ID
	 * @return 用户信息
	 */
	UserVO selectUserVoById(Long id);

	/**
	 * 保存用户信息
	 * @param userDto DTO 对象
	 * @return success/fail
	 */
	Boolean saveUser(UserDTO userDto);

	/**
	 * 锁定用户
	 * @param user
	 * @return
	 */
	R<Boolean> lockUser(SysUser user);

	/**
	 * 修改密码
	 * @param userDto 用户信息
	 * @return
	 */
	R changePassword(UserDTO userDto);

	/**
	 * 校验密码
	 * @param password 密码明文
	 * @return
	 */
	R checkPassword(String password);


	Page<UserVO> testJoinPage(Page<UserVO> page, UserDTO userDTO);
}
