
package com.kxs.lhb.system.biz.service.impl;

import cn.hutool.core.util.ArrayUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.kxs.lhb.system.biz.service.SysLogService;
import com.kxs.lhb.system.api.dto.admin.SysLogDTO;
import com.kxs.lhb.system.biz.mapper.SysLogMapper;
import com.kxs.lhb.system.api.model.SysLog;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 日志表 服务实现类
 * </p>
 *
 * @author 秃顶的码农
 * @since 2023-11-20
 */
@Service
public class SysLogServiceImpl extends ServiceImpl<SysLogMapper, SysLog> implements SysLogService {

	@Override
	public Page<SysLog> getLogByPage(Page<SysLog> page, SysLogDTO sysLog) {

		LambdaQueryWrapper<SysLog> wrapper = Wrappers.lambdaQuery();
		if (StrUtil.isNotBlank(sysLog.getLogType())) {
			wrapper.eq(SysLog::getLogType, sysLog.getLogType());
		}
		if (StrUtil.isNotBlank(sysLog.getTitle())) {
			wrapper.eq(SysLog::getTitle, sysLog.getTitle());
		}
		if (StrUtil.isNotBlank(sysLog.getRequestUri())) {
			wrapper.eq(SysLog::getRequestUri, sysLog.getRequestUri());
		}

		if (ArrayUtil.isNotEmpty(sysLog.getCreateTime())) {
			wrapper.ge(SysLog::getCreateTime, sysLog.getCreateTime()[0])
				.le(SysLog::getCreateTime, sysLog.getCreateTime()[1]);
		}
		wrapper.orderByDesc(SysLog::getCreateTime);

		return baseMapper.selectPage(page, wrapper);
	}

	/**
	 * 插入日志
	 * @param sysLog 日志对象
	 * @return true/false
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public Boolean saveLog(SysLog sysLog) {
		baseMapper.insert(sysLog);
		return Boolean.TRUE;
	}

}
